@@ -194,7 +194,7 @@ class URLBase:
             asset if isinstance(asset, AppriseAsset) else AppriseAsset()
 
         # Certificate Verification (for SSL calls); default to being enabled
-        self.verify_certificate = kwargs.get('verify', True)
+        self.verify_certificate = parse_bool(kwargs.get('verify', True))
 
         # Secure Mode
         self.secure = kwargs.get('secure', False)
@@ -222,24 +222,22 @@ class URLBase:
             self.password = URLBase.unquote(self.password)
 
         # Store our Timeout Variables
-        if 'socket_read_timeout' in kwargs:
+        if 'rto' in kwargs:
             try:
-                self.socket_read_timeout = \
-                    float(kwargs.get('socket_read_timeout'))
+                self.socket_read_timeout = float(kwargs.get('rto'))
             except (TypeError, ValueError):
                 self.logger.warning(
                     'Invalid socket read timeout (rto) was specified {}'
-                    .format(kwargs.get('socket_read_timeout')))
+                    .format(kwargs.get('rto')))
 
-        if 'socket_connect_timeout' in kwargs:
+        if 'cto' in kwargs:
             try:
-                self.socket_connect_timeout = \
-                    float(kwargs.get('socket_connect_timeout'))
+                self.socket_connect_timeout = float(kwargs.get('cto'))
 
             except (TypeError, ValueError):
                 self.logger.warning(
                     'Invalid socket connect timeout (cto) was specified {}'
-                    .format(kwargs.get('socket_connect_timeout')))
+                    .format(kwargs.get('cto')))
 
         if 'tag' in kwargs:
             # We want to associate some tags with our notification service.
@@ -598,7 +596,7 @@ class URLBase:
         }
 
     @staticmethod
-    def parse_url(url, verify_host=True):
+    def parse_url(url, verify_host=True, plus_to_space=False):
         """Parses the URL and returns it broken apart into a dictionary.
 
         This is very specific and customized for Apprise.
@@ -618,7 +616,8 @@ class URLBase:
         """
 
         results = parse_url(
-            url, default_schema='unknown', verify_host=verify_host)
+            url, default_schema='unknown', verify_host=verify_host,
+            plus_to_space=plus_to_space)
 
         if not results:
             # We're done; we failed to parse our url
@@ -646,11 +645,11 @@ class URLBase:
 
         # Store our socket read timeout if specified
         if 'rto' in results['qsd']:
-            results['socket_read_timeout'] = results['qsd']['rto']
+            results['rto'] = results['qsd']['rto']
 
         # Store our socket connect timeout if specified
         if 'cto' in results['qsd']:
-            results['socket_connect_timeout'] = results['qsd']['cto']
+            results['cto'] = results['qsd']['cto']
 
         if 'port' in results['qsd']:
             results['port'] = results['qsd']['port']
