@@ -26,7 +26,6 @@
 import click
 import logging
 import platform
-import six
 import sys
 import os
 import re
@@ -273,10 +272,10 @@ def main(body, title, config, attach, urls, notification_type, theme, tag,
         # Set the theme
         theme=theme,
 
-        # Async mode is only used for Python v3+ and allows a user to send
-        # all of their notifications asyncronously.  This was made an option
-        # incase there are problems in the future where it's better that
-        # everything run sequentially/syncronously instead.
+        # Async mode allows a user to send all of their notifications
+        # asynchronously. This was made an option incase there are problems
+        # in the future where it is better that everything runs sequentially/
+        # synchronously instead.
         async_mode=disable_async is not True,
 
         # Load our plugins
@@ -296,11 +295,11 @@ def main(body, title, config, attach, urls, notification_type, theme, tag,
         for entry in plugins:
             protocols = [] if not entry['protocols'] else \
                 [p for p in entry['protocols']
-                 if isinstance(p, six.string_types)]
+                 if isinstance(p, str)]
             protocols.extend(
                 [] if not entry['secure_protocols'] else
                 [p for p in entry['secure_protocols']
-                 if isinstance(p, six.string_types)])
+                 if isinstance(p, str)])
 
             if len(protocols) == 1:
                 # Simplify view by swapping {schema} with the single
