@@ -180,7 +180,7 @@ class NotifyBase(BASE_OBJECT):
 
         """
 
-        super(NotifyBase, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
         if 'format' in kwargs:
             # Store the specified format if specified
@@ -423,13 +423,13 @@ class NotifyBase(BASE_OBJECT):
             'overflow': self.overflow_mode,
         }
 
-        params.update(super(NotifyBase, self).url_parameters(*args, **kwargs))
+        params.update(super().url_parameters(*args, **kwargs))
 
         # return default parameters
         return params
 
     @staticmethod
-    def parse_url(url, verify_host=True):
+    def parse_url(url, verify_host=True, plus_to_space=False):
         """Parses the URL and returns it broken apart into a dictionary.
 
         This is very specific and customized for Apprise.
@@ -447,7 +447,8 @@ class NotifyBase(BASE_OBJECT):
             A dictionary is returned containing the URL fully parsed if
             successful, otherwise None is returned.
         """
-        results = URLBase.parse_url(url, verify_host=verify_host)
+        results = URLBase.parse_url(
+            url, verify_host=verify_host, plus_to_space=plus_to_space)
 
         if not results:
             # We're done; we failed to parse our url
