@@ -23,8 +23,10 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 
+import dataclasses
 import re
 import smtplib
+import typing as t
 from email.mime.text import MIMEText
 from email.mime.application import MIMEApplication
 from email.mime.multipart import MIMEMultipart
@@ -41,6 +43,7 @@ from ..common import NotifyFormat, NotifyType
 from ..conversion import convert_between
 from ..utils import is_email, parse_emails
 from ..AppriseLocale import gettext_lazy as _
+from ..logger import logger
 
 # Globally Default encoding mode set to Quoted Printable.
 charset.add_charset('utf-8', charset.QP, charset.QP, 'utf-8')
@@ -109,7 +112,7 @@ EMAIL_TEMPLATES = (
         'Microsoft Hotmail',
         re.compile(
             r'^((?P<label>[^+]+)\+)?(?P<id>[^@]+)@'
-            r'(?P<domain>(outlook|hotmail|live)\.com(\.au)?)$', re.I),
+            r'(?P<domain>(hotmail|live)\.com(\.au)?)$', re.I),
         {
             'port': 587,
             'smtp_host': 'smtp-mail.outlook.com',
@@ -119,6 +122,21 @@ EMAIL_TEMPLATES = (
         },
     ),
 
+    # Microsoft Outlook
+    (
+        'Microsoft Outlook',
+        re.compile(
+            r'^((?P<label>[^+]+)\+)?(?P<id>[^@]+)@'
+            r'(?P<domain>(smtp\.)?outlook\.com(\.au)?)$', re.I),
+        {
+            'port': 587,
+            'smtp_host': 'smtp.outlook.com',
+            'secure': True,
+            'secure_mode': SecureMailMode.STARTTLS,
+            'login_type': (WebBaseLogin.EMAIL, )
+        },
+    ),
+
     # Microsoft Office 365 (Email Server)
     # You must specify an authenticated sender address in the from= settings
     # and a valid email in the to= to deliver your emails to
@@ -282,6 +300,13 @@ EMAIL_TEMPLATES = (
 )
 
 
+@dataclasses.dataclass
+class EmailMessage:
+    recipient: str
+    to_addrs: t.List[str]
+    body: str
+
+
 class NotifyEmail(NotifyBase):
     """
     A wrapper to Email Notifications
@@ -373,7 +398,7 @@ class NotifyEmail(NotifyBase):
         'name': {
             'name': _('From Name'),
             'type': 'string',
-            'map_to': 'from_name',
+            'map_to': 'from_addr',
         },
         'cc': {
             'name': _('Carbon Copy'),
@@ -410,16 +435,16 @@ class NotifyEmail(NotifyBase):
         },
     }
 
-    def __init__(self, smtp_host=None, from_name=None,
-                 from_addr=None, secure_mode=None, targets=None, cc=None,
-                 bcc=None, reply_to=None, headers=None, **kwargs):
+    def __init__(self, smtp_host=None, from_addr=None, secure_mode=None,
+                 targets=None, cc=None, bcc=None, reply_to=None, headers=None,
+                 **kwargs):
         """
         Initialize Email Object
 
         The smtp_host and secure_mode can be automatically detected depending
         on how the URL was built
         """
-        super(NotifyEmail, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
         # Handle SMTP vs SMTPS (Secure vs UnSecure)
         if not self.port:
@@ -451,31 +476,35 @@ class NotifyEmail(NotifyBase):
 
         # Now we want to construct the To and From email
         # addresses from the URL provided
-        self.from_addr = from_addr
+        self.from_addr = [False, '']
 
-        if self.user and not self.from_addr:
-            # detect our email address
-            self.from_addr = '{}@{}'.format(
+        if self.user and self.host:
+            # Prepare the bases of our email
+            self.from_addr = [self.app_id, '{}@{}'.format(
                 re.split(r'[\s@]+', self.user)[0],
                 self.host,
-            )
+            )]
 
-        result = is_email(self.from_addr)
+        if from_addr:
+            result = is_email(from_addr)
+            if result:
+                self.from_addr = (
+                    result['name'] if result['name'] else False,
+                    result['full_email'])
+            else:
+                self.from_addr[0] = from_addr
+
+        result = is_email(self.from_addr[1])
         if not result:
             # Parse Source domain based on from_addr
-            msg = 'Invalid ~From~ email specified: {}'.format(self.from_addr)
+            msg = 'Invalid ~From~ email specified: {}'.format(
+                '{} <{}>'.format(self.from_addr[0], self.from_addr[1])
+                if self.from_addr[0] else '{}'.format(self.from_addr[1]))
             self.logger.warning(msg)
             raise TypeError(msg)
 
-        # Store our email address
-        self.from_addr = result['full_email']
-
-        # Set our from name
-        self.from_name = from_name if from_name else result['name']
-
         # Store our lookup
-        self.names[self.from_addr] = \
-            self.from_name if self.from_name else False
+        self.names[self.from_addr[1]] = self.from_addr[0]
 
         # Now detect the SMTP Server
         self.smtp_host = \
@@ -508,8 +537,7 @@ class NotifyEmail(NotifyBase):
 
         else:
             # If our target email list is empty we want to add ourselves to it
-            self.targets.append(
-                (self.from_name if self.from_name else False, self.from_addr))
+            self.targets.append((False, self.from_addr[1]))
 
         # Validate recipients (cc:) and drop bad ones:
         for recipient in parse_emails(cc):
@@ -656,18 +684,14 @@ class NotifyEmail(NotifyBase):
         Perform Email Notification
         """
 
-        # Initialize our default from name
-        from_name = self.from_name if self.from_name else self.app_desc
-
-        # error tracking (used for function return)
-        has_error = False
-
         if not self.targets:
             # There is no one to email; we're done
             self.logger.warning(
                 'There are no Email recipients to notify')
             return False
 
+        messages: t.List[EmailMessage] = []
+
         # Create a copy of the targets list
         emails = list(self.targets)
         while len(emails):
@@ -700,7 +724,9 @@ class NotifyEmail(NotifyBase):
                     for addr in reply_to]
 
             self.logger.debug(
-                'Email From: {} <{}>'.format(from_name, self.from_addr))
+                'Email From: {}'.format(
+                    formataddr(self.from_addr, charset='utf-8')))
+
             self.logger.debug('Email To: {}'.format(to_addr))
             if cc:
                 self.logger.debug('Email Cc: {}'.format(', '.join(cc)))
@@ -763,9 +789,7 @@ class NotifyEmail(NotifyBase):
                 base[k] = Header(v, self._get_charset(v))
 
             base['Subject'] = Header(title, self._get_charset(title))
-            base['From'] = formataddr(
-                (from_name if from_name else False, self.from_addr),
-                charset='utf-8')
+            base['From'] = formataddr(self.from_addr, charset='utf-8')
             base['To'] = formataddr((to_name, to_addr), charset='utf-8')
             base['Message-ID'] = make_msgid(domain=self.smtp_host)
             base['Date'] = \
@@ -778,58 +802,79 @@ class NotifyEmail(NotifyBase):
             if reply_to:
                 base['Reply-To'] = ','.join(reply_to)
 
-            # bind the socket variable to the current namespace
-            socket = None
+            message = EmailMessage(
+                recipient=to_addr,
+                to_addrs=[to_addr] + list(cc) + list(bcc),
+                body=base.as_string())
+            messages.append(message)
 
-            # Always call throttle before any remote server i/o is made
-            self.throttle()
+        return self.submit(messages)
 
-            try:
-                self.logger.debug('Connecting to remote SMTP server...')
-                socket_func = smtplib.SMTP
-                if self.secure and self.secure_mode == SecureMailMode.SSL:
-                    self.logger.debug('Securing connection with SSL...')
-                    socket_func = smtplib.SMTP_SSL
+    def submit(self, messages: t.List[EmailMessage]):
 
-                socket = socket_func(
-                    self.smtp_host,
-                    self.port,
-                    None,
-                    timeout=self.socket_connect_timeout,
-                )
+        # error tracking (used for function return)
+        has_error = False
 
-                if self.secure and self.secure_mode == SecureMailMode.STARTTLS:
-                    # Handle Secure Connections
-                    self.logger.debug('Securing connection with STARTTLS...')
-                    socket.starttls()
+        # bind the socket variable to the current namespace
+        socket = None
 
-                if self.user and self.password:
-                    # Apply Login credetials
-                    self.logger.debug('Applying user credentials...')
-                    socket.login(self.user, self.password)
+        # Always call throttle before any remote server i/o is made
+        self.throttle()
 
-                # Send the email
-                socket.sendmail(
-                    self.from_addr,
-                    [to_addr] + list(cc) + list(bcc),
-                    base.as_string())
+        try:
+            self.logger.debug('Connecting to remote SMTP server...')
+            socket_func = smtplib.SMTP
+            if self.secure and self.secure_mode == SecureMailMode.SSL:
+                self.logger.debug('Securing connection with SSL...')
+                socket_func = smtplib.SMTP_SSL
 
-                self.logger.info(
-                    'Sent Email notification to "{}".'.format(to_addr))
+            socket = socket_func(
+                self.smtp_host,
+                self.port,
+                None,
+                timeout=self.socket_connect_timeout,
+            )
 
-            except (SocketError, smtplib.SMTPException, RuntimeError) as e:
-                self.logger.warning(
-                    'A Connection error occurred sending Email '
-                    'notification to {}.'.format(self.smtp_host))
-                self.logger.debug('Socket Exception: %s' % str(e))
+            if self.secure and self.secure_mode == SecureMailMode.STARTTLS:
+                # Handle Secure Connections
+                self.logger.debug('Securing connection with STARTTLS...')
+                socket.starttls()
 
-                # Mark our failure
-                has_error = True
+            if self.user and self.password:
+                # Apply Login credetials
+                self.logger.debug('Applying user credentials...')
+                socket.login(self.user, self.password)
 
-            finally:
-                # Gracefully terminate the connection with the server
-                if socket is not None:  # pragma: no branch
-                    socket.quit()
+            # Send the emails
+            for message in messages:
+                try:
+                    socket.sendmail(
+                        self.from_addr[1],
+                        message.to_addrs,
+                        message.body)
+
+                    self.logger.info(
+                        f'Sent Email notification to "{message.recipient}".')
+                except (SocketError, smtplib.SMTPException, RuntimeError) as e:
+                    self.logger.warning(
+                        f'Sending email to "{message.recipient}" failed. '
+                        f'Reason: {e}')
+
+                    # Mark as failure
+                    has_error = True
+
+        except (SocketError, smtplib.SMTPException, RuntimeError) as e:
+            self.logger.warning(
+                f'Connection error while submitting email to {self.smtp_host}.'
+                f' Reason: {e}')
+
+            # Mark as failure
+            has_error = True
+
+        finally:
+            # Gracefully terminate the connection with the server
+            if socket is not None:  # pragma: no branch
+                socket.quit()
 
         return not has_error
 
@@ -839,12 +884,7 @@ class NotifyEmail(NotifyBase):
         """
 
         # Define an URL parameters
-        params = {
-            'from': self.from_addr,
-            'mode': self.secure_mode,
-            'smtp': self.smtp_host,
-            'user': self.user,
-        }
+        params = {}
 
         # Append our headers into our parameters
         params.update({'+{}'.format(k): v for k, v in self.headers.items()})
@@ -852,30 +892,60 @@ class NotifyEmail(NotifyBase):
         # Extend our parameters
         params.update(self.url_parameters(privacy=privacy, *args, **kwargs))
 
-        if self.from_name:
-            params['name'] = self.from_name
+        from_addr = None
+        if len(self.targets) == 1 and self.targets[0][1] != self.from_addr[1]:
+            # A custom email was provided
+            from_addr = self.from_addr[1]
+
+        if self.smtp_host != self.host:
+            # Apply our SMTP Host only if it differs from the provided hostname
+            params['smtp'] = self.smtp_host
+
+        if self.secure:
+            # Mode is only requried if we're dealing with a secure connection
+            params['mode'] = self.secure_mode
+
+        if self.from_addr[0] and self.from_addr[0] != self.app_id:
+            # A custom name was provided
+            params['from'] = self.from_addr[0] if not from_addr else \
+                formataddr((self.from_addr[0], from_addr), charset='utf-8')
+
+        elif from_addr:
+            params['from'] = formataddr((False, from_addr), charset='utf-8')
+
+        elif not self.user:
+            params['from'] = \
+                formataddr((False, self.from_addr[1]), charset='utf-8')
 
         if len(self.cc) > 0:
             # Handle our Carbon Copy Addresses
-            params['cc'] = ','.join(
-                ['{}{}'.format(
-                    '' if not e not in self.names
-                    else '{}:'.format(self.names[e]), e) for e in self.cc])
+            params['cc'] = ','.join([
+                formataddr(
+                    (self.names[e] if e in self.names else False, e),
+                    # Swap comma for it's escaped url code (if detected) since
+                    # we're using that as a delimiter
+                    charset='utf-8').replace(',', '%2C')
+                for e in self.cc])
 
         if len(self.bcc) > 0:
             # Handle our Blind Carbon Copy Addresses
-            params['bcc'] = ','.join(
-                ['{}{}'.format(
-                    '' if not e not in self.names
-                    else '{}:'.format(self.names[e]), e) for e in self.bcc])
+            params['bcc'] = ','.join([
+                formataddr(
+                    (self.names[e] if e in self.names else False, e),
+                    # Swap comma for it's escaped url code (if detected) since
+                    # we're using that as a delimiter
+                    charset='utf-8').replace(',', '%2C')
+                for e in self.bcc])
 
         if self.reply_to:
             # Handle our Reply-To Addresses
-            params['reply'] = ','.join(
-                ['{}{}'.format(
-                    '' if not e not in self.names
-                    else '{}:'.format(self.names[e]), e)
-                    for e in self.reply_to])
+            params['reply'] = ','.join([
+                formataddr(
+                    (self.names[e] if e in self.names else False, e),
+                    # Swap comma for it's escaped url code (if detected) since
+                    # we're using that as a delimiter
+                    charset='utf-8').replace(',', '%2C')
+                for e in self.reply_to])
 
         # pull email suffix from username (if present)
         user = None if not self.user else self.user.split('@')[0]
@@ -902,7 +972,7 @@ class NotifyEmail(NotifyBase):
         # or not
         has_targets = \
             not (len(self.targets) == 1
-                 and self.targets[0][1] == self.from_addr)
+                 and self.targets[0][1] == self.from_addr[1])
 
         return '{schema}://{auth}{hostname}{port}/{targets}?{params}'.format(
             schema=self.secure_protocol if self.secure else self.protocol,
@@ -946,14 +1016,24 @@ class NotifyEmail(NotifyBase):
         if 'from' in results['qsd'] and len(results['qsd']['from']):
             from_addr = NotifyEmail.unquote(results['qsd']['from'])
 
+            if 'name' in results['qsd'] and len(results['qsd']['name']):
+                # Depricate use of both `from=` and `name=` in the same url as
+                # they will be synomomus of one another in the future.
+                from_addr = formataddr(
+                    (NotifyEmail.unquote(results['qsd']['name']), from_addr),
+                    charset='utf-8')
+                logger.warning(
+                    'Email name= and from= are synonymous; '
+                    'use one or the other.')
+
+        elif 'name' in results['qsd'] and len(results['qsd']['name']):
+            # Extract from name to associate with from address
+            from_addr = NotifyEmail.unquote(results['qsd']['name'])
+
         # Attempt to detect 'to' email address
         if 'to' in results['qsd'] and len(results['qsd']['to']):
             results['targets'].append(results['qsd']['to'])
 
-        if 'name' in results['qsd'] and len(results['qsd']['name']):
-            # Extract from name to associate with from address
-            results['from_name'] = NotifyEmail.unquote(results['qsd']['name'])
-
         # Store SMTP Host if specified
         if 'smtp' in results['qsd'] and len(results['qsd']['smtp']):
             # Extract the smtp server
