@@ -125,9 +125,14 @@ class NotifyJSON(NotifyBase):
             'name': _('Payload Extras'),
             'prefix': ':',
         },
+        'params': {
+            'name': _('GET Params'),
+            'prefix': '-',
+        },
     }
 
-    def __init__(self, headers=None, method=None, payload=None, **kwargs):
+    def __init__(self, headers=None, method=None, payload=None, params=None,
+                 **kwargs):
         """
         Initialize JSON Object
 
@@ -135,7 +140,7 @@ class NotifyJSON(NotifyBase):
         additionally include as part of the server headers to post with
 
         """
-        super(NotifyJSON, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
         self.fullpath = kwargs.get('fullpath')
         if not isinstance(self.fullpath, str):
@@ -149,6 +154,11 @@ class NotifyJSON(NotifyBase):
             self.logger.warning(msg)
             raise TypeError(msg)
 
+        self.params = {}
+        if params:
+            # Store our extra headers
+            self.params.update(params)
+
         self.headers = {}
         if headers:
             # Store our extra headers
@@ -177,6 +187,9 @@ class NotifyJSON(NotifyBase):
         # Append our headers into our parameters
         params.update({'+{}'.format(k): v for k, v in self.headers.items()})
 
+        # Append our GET params into our parameters
+        params.update({'-{}'.format(k): v for k, v in self.params.items()})
+
         # Append our payload extra's into our parameters
         params.update(
             {':{}'.format(k): v for k, v in self.payload_extras.items()})
@@ -214,6 +227,7 @@ class NotifyJSON(NotifyBase):
         Perform JSON Notification
         """
 
+        # Prepare HTTP Headers
         headers = {
             'User-Agent': self.app_id,
             'Content-Type': 'application/json'
@@ -307,6 +321,7 @@ class NotifyJSON(NotifyBase):
             r = method(
                 url,
                 data=dumps(payload),
+                params=self.params,
                 headers=headers,
                 auth=auth,
                 verify=self.verify_certificate,
@@ -364,6 +379,10 @@ class NotifyJSON(NotifyBase):
         results['headers'] = {NotifyJSON.unquote(x): NotifyJSON.unquote(y)
                               for x, y in results['qsd+'].items()}
 
+        # Add our GET paramters in the event the user wants to pass these along
+        results['params'] = {NotifyJSON.unquote(x): NotifyJSON.unquote(y)
+                             for x, y in results['qsd-'].items()}
+
         # Set method if not otherwise set
         if 'method' in results['qsd'] and len(results['qsd']['method']):
             results['method'] = NotifyJSON.unquote(results['qsd']['method'])
