@@ -132,20 +132,6 @@ class NotifyMQTT(NotifyBase):
     # through their network flow at once.
     mqtt_inflight_messages = 200
 
-    # Taken from https://golang.org/src/crypto/x509/root_linux.go
-    CA_CERTIFICATE_FILE_LOCATIONS = [
-        # Debian/Ubuntu/Gentoo etc.
-        "/etc/ssl/certs/ca-certificates.crt",
-        # Fedora/RHEL 6
-        "/etc/pki/tls/certs/ca-bundle.crt",
-        # OpenSUSE
-        "/etc/ssl/ca-bundle.pem",
-        # OpenELEC
-        "/etc/pki/tls/cacert.pem",
-        # CentOS/RHEL 7
-        "/etc/pki/ca-trust/extracted/pem/tls-ca-bundle.pem",
-    ]
-
     # Define object templates
     templates = (
         '{schema}://{user}@{host}/{topic}',
@@ -223,7 +209,7 @@ class NotifyMQTT(NotifyBase):
         Initialize MQTT Object
         """
 
-        super(NotifyMQTT, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
         # Initialize topics
         self.topics = parse_list(targets)
@@ -264,6 +250,9 @@ class NotifyMQTT(NotifyBase):
         self.ca_certs = None
         if self.secure:
             # verify SSL key or abort
+            # TODO: There is no error reporting or aborting here?
+            #       It could be useful to inform the user _where_ Apprise
+            #       tried to find the root CA certificates file.
             self.ca_certs = next(
                 (cert for cert in self.CA_CERTIFICATE_FILE_LOCATIONS
                  if isfile(cert)), None)
@@ -316,9 +305,9 @@ class NotifyMQTT(NotifyBase):
 
                 if self.secure:
                     if self.ca_certs is None:
-                        self.logger.warning(
-                            'MQTT Secure comunication can not be verified; '
-                            'no local CA certificate file')
+                        self.logger.error(
+                            'MQTT secure communication can not be verified, '
+                            'CA certificates file missing')
                         return False
 
                     self.client.tls_set(
@@ -528,3 +517,38 @@ class NotifyMQTT(NotifyBase):
 
         # return results
         return results
+
+    @property
+    def CA_CERTIFICATE_FILE_LOCATIONS(self):
+        """
+        Return possible locations to root certificate authority (CA) bundles.
+
+        Taken from https://golang.org/src/crypto/x509/root_linux.go
+        TODO: Maybe refactor to a general utility function?
+        """
+        candidates = [
+            # Debian/Ubuntu/Gentoo etc.
+            "/etc/ssl/certs/ca-certificates.crt",
+            # Fedora/RHEL 6
+            "/etc/pki/tls/certs/ca-bundle.crt",
+            # OpenSUSE
+            "/etc/ssl/ca-bundle.pem",
+            # OpenELEC
+            "/etc/pki/tls/cacert.pem",
+            # CentOS/RHEL 7
+            "/etc/pki/ca-trust/extracted/pem/tls-ca-bundle.pem",
+            # macOS Homebrew; brew install ca-certificates
+            "/usr/local/etc/ca-certificates/cert.pem",
+        ]
+
+        # Certifi provides Mozilla’s carefully curated collection of Root
+        # Certificates for validating the trustworthiness of SSL certificates
+        # while verifying the identity of TLS hosts. It has been extracted from
+        # the Requests project.
+        try:
+            import certifi
+            candidates.append(certifi.where())
+        except ImportError:  # pragma: no cover
+            pass
+
+        return candidates
