@@ -60,6 +60,7 @@ from ..utils import parse_emails
 from ..utils import parse_bool
 from ..utils import is_email
 from ..utils import validate_regex
+from ..logger import logger
 from ..AppriseLocale import gettext_lazy as _
 
 # Provide some known codes Mailgun uses and what they translate to:
@@ -158,7 +159,10 @@ class NotifyMailgun(NotifyBase):
         'name': {
             'name': _('From Name'),
             'type': 'string',
-            'map_to': 'from_name',
+            'map_to': 'from_addr',
+        },
+        'from': {
+            'alias_of': 'name',
         },
         'region': {
             'name': _('Region Name'),
@@ -197,13 +201,13 @@ class NotifyMailgun(NotifyBase):
         },
     }
 
-    def __init__(self, apikey, targets, cc=None, bcc=None, from_name=None,
+    def __init__(self, apikey, targets, cc=None, bcc=None, from_addr=None,
                  region_name=None, headers=None, tokens=None, batch=False,
                  **kwargs):
         """
         Initialize Mailgun Object
         """
-        super(NotifyMailgun, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
         # API Key (associated with project)
         self.apikey = validate_regex(apikey)
@@ -260,12 +264,20 @@ class NotifyMailgun(NotifyBase):
             raise TypeError(msg)
 
         # Get our From username (if specified)
-        self.from_name = from_name
+        self.from_addr = [
+            self.app_id, '{user}@{host}'.format(
+                user=self.user, host=self.host)]
 
-        # Get our from email address
-        self.from_addr = '{user}@{host}'.format(user=self.user, host=self.host)
+        if from_addr:
+            result = is_email(from_addr)
+            if result:
+                self.from_addr = (
+                    result['name'] if result['name'] else False,
+                    result['full_email'])
+            else:
+                self.from_addr[0] = from_addr
 
-        if not is_email(self.from_addr):
+        if not is_email(self.from_addr[1]):
             # Parse Source domain based on from_addr
             msg = 'Invalid ~From~ email format: {}'.format(self.from_addr)
             self.logger.warning(msg)
@@ -288,8 +300,7 @@ class NotifyMailgun(NotifyBase):
 
         else:
             # If our target email list is empty we want to add ourselves to it
-            self.targets.append(
-                (self.from_name if self.from_name else False, self.from_addr))
+            self.targets.append((False, self.from_addr[1]))
 
         # Validate recipients (cc:) and drop bad ones:
         for recipient in parse_emails(cc):
@@ -383,9 +394,7 @@ class NotifyMailgun(NotifyBase):
 
                     return False
 
-        reply_to = formataddr(
-            (self.from_name if self.from_name else False,
-             self.from_addr), charset='utf-8')
+        reply_to = formataddr(self.from_addr, charset='utf-8')
 
         # Prepare our payload
         payload = {
@@ -581,9 +590,9 @@ class NotifyMailgun(NotifyBase):
         # Extend our parameters
         params.update(self.url_parameters(privacy=privacy, *args, **kwargs))
 
-        if self.from_name is not None:
-            # from_name specified; pass it back on the url
-            params['name'] = self.from_name
+        if self.from_addr[0]:
+            # from_addr specified; pass it back on the url
+            params['name'] = self.from_addr[0]
 
         if self.cc:
             # Handle our Carbon Copy Addresses
@@ -637,9 +646,24 @@ class NotifyMailgun(NotifyBase):
             # We're done - no API Key found
             results['apikey'] = None
 
-        if 'name' in results['qsd'] and len(results['qsd']['name']):
+        # Attempt to detect 'from' email address
+        if 'from' in results['qsd'] and len(results['qsd']['from']):
+            results['from_addr'] = \
+                NotifyMailgun.unquote(results['qsd']['from'])
+
+            if 'name' in results['qsd'] and len(results['qsd']['name']):
+                # Depricate use of both `from=` and `name=` in the same url as
+                # they will be synomomus of one another in the future.
+                results['from_addr'] = formataddr(
+                    (NotifyMailgun.unquote(results['qsd']['name']),
+                     results['from_addr']), charset='utf-8')
+                logger.warning(
+                    'Mailgun name= and from= are synonymous; '
+                    'use one or the other.')
+
+        elif 'name' in results['qsd'] and len(results['qsd']['name']):
             # Extract from name to associate with from address
-            results['from_name'] = \
+            results['from_addr'] = \
                 NotifyMailgun.unquote(results['qsd']['name'])
 
         if 'region' in results['qsd'] and len(results['qsd']['region']):
