@@ -178,7 +178,7 @@ class NotifyOneSignal(NotifyBase):
         Initialize OneSignal
 
         """
-        super(NotifyOneSignal, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
         # The apikey associated with the account
         self.apikey = validate_regex(apikey)
