@@ -159,7 +159,7 @@ class NotifySMTP2Go(NotifyBase):
         """
         Initialize SMTP2Go Object
         """
-        super(NotifySMTP2Go, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
         # API Key (associated with project)
         self.apikey = validate_regex(apikey)
