@@ -183,7 +183,7 @@ class NotifyStreamlabs(NotifyBase):
         Initialize Streamlabs Object
 
         """
-        super(NotifyStreamlabs, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
         # access token is generated by user
         # using https://streamlabs.com/api/v1.0/token
