@@ -75,7 +75,7 @@ class NotifyTwitter(NotifyBase):
     service_url = 'https://twitter.com/'
 
     # The default secure protocol is twitter.
-    secure_protocol = 'twitter'
+    secure_protocol = ('twitter', 'tweet')
 
     # A URL that takes you to the setup/help of the specific protocol
     setup_url = 'https://github.com/caronc/apprise/wiki/Notify_twitter'
@@ -194,7 +194,7 @@ class NotifyTwitter(NotifyBase):
         Initialize Twitter Object
 
         """
-        super(NotifyTwitter, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
         self.ckey = validate_regex(ckey)
         if not self.ckey:
@@ -221,21 +221,21 @@ class NotifyTwitter(NotifyBase):
             raise TypeError(msg)
 
         # Store our webhook mode
-        self.mode = None \
+        self.mode = self.template_args['mode']['default'] \
             if not isinstance(mode, str) else mode.lower()
 
-        # Set Cache Flag
-        self.cache = cache
-
-        # Prepare Image Batch Mode Flag
-        self.batch = batch
-
         if self.mode not in TWITTER_MESSAGE_MODES:
             msg = 'The Twitter message mode specified ({}) is invalid.' \
                 .format(mode)
             self.logger.warning(msg)
             raise TypeError(msg)
 
+        # Set Cache Flag
+        self.cache = cache
+
+        # Prepare Image Batch Mode Flag
+        self.batch = batch
+
         # Track any errors
         has_error = False
 
@@ -249,7 +249,7 @@ class NotifyTwitter(NotifyBase):
 
             has_error = True
             self.logger.warning(
-                'Dropped invalid user ({}) specified.'.format(target),
+                'Dropped invalid Twitter user ({}) specified.'.format(target),
             )
 
         if has_error and not self.targets:
@@ -261,6 +261,10 @@ class NotifyTwitter(NotifyBase):
             self.logger.warning(msg)
             raise TypeError(msg)
 
+        # Initialize our cache values
+        self._whoami_cache = None
+        self._user_cache = {}
+
         return
 
     def send(self, body, title='', notify_type=NotifyType.INFO, attach=None,
@@ -293,7 +297,7 @@ class NotifyTwitter(NotifyBase):
                     continue
 
                 self.logger.debug(
-                    'Preparing Twiter attachment {}'.format(
+                    'Preparing Twitter attachment {}'.format(
                         attachment.url(privacy=True)))
 
                 # Upload our image and get our id associated with it
@@ -536,16 +540,9 @@ class NotifyTwitter(NotifyBase):
 
         """
 
-        # Prepare a whoami key; this is to prevent conflict with other
-        # NotifyTwitter declarations that may or may not use a different
-        # set of authentication keys
-        whoami_key = '{}{}{}{}'.format(
-            self.ckey, self.csecret, self.akey, self.asecret)
-
-        if lazy and hasattr(NotifyTwitter, '_whoami_cache') \
-                and whoami_key in getattr(NotifyTwitter, '_whoami_cache'):
+        if lazy and self._whoami_cache is not None:
             # Use cached response
-            return getattr(NotifyTwitter, '_whoami_cache')[whoami_key]
+            return self._whoami_cache
 
         # Contains a mapping of screen_name to id
         results = {}
@@ -560,22 +557,11 @@ class NotifyTwitter(NotifyBase):
         if postokay:
             try:
                 results[response['screen_name']] = response['id']
+                self._whoami_cache = {
+                    response['screen_name']: response['id'],
+                }
 
-                if lazy:
-                    # Cache our response for future references
-                    if not hasattr(NotifyTwitter, '_whoami_cache'):
-                        setattr(
-                            NotifyTwitter, '_whoami_cache',
-                            {whoami_key: results})
-                    else:
-                        getattr(NotifyTwitter, '_whoami_cache')\
-                            .update({whoami_key: results})
-
-                    # Update our user cache as well
-                    if not hasattr(NotifyTwitter, '_user_cache'):
-                        setattr(NotifyTwitter, '_user_cache', results)
-                    else:
-                        getattr(NotifyTwitter, '_user_cache').update(results)
+                self._user_cache.update(results)
 
             except (TypeError, KeyError):
                 pass
@@ -595,10 +581,10 @@ class NotifyTwitter(NotifyBase):
         # Build a unique set of names
         names = parse_list(screen_name)
 
-        if lazy and hasattr(NotifyTwitter, '_user_cache'):
+        if lazy and self._user_cache:
             # Use cached response
-            results = {k: v for k, v in getattr(
-                NotifyTwitter, '_user_cache').items() if k in names}
+            results = {
+                k: v for k, v in self._user_cache.items() if k in names}
 
             # limit our names if they already exist in our cache
             names = [name for name in names if name not in results]
@@ -612,7 +598,7 @@ class NotifyTwitter(NotifyBase):
         # https://developer.twitter.com/en/docs/accounts-and-users/\
         #     follow-search-get-users/api-reference/get-users-lookup
         for i in range(0, len(names), 100):
-            # Send Twitter DM
+            # Look up our names by their screen_name
             postokay, response = self._fetch(
                 self.twitter_lookup,
                 payload={
@@ -635,11 +621,7 @@ class NotifyTwitter(NotifyBase):
 
         # Cache our response for future use; this saves on un-nessisary extra
         # hits against the Twitter API when we already know the answer
-        if lazy:
-            if not hasattr(NotifyTwitter, '_user_cache'):
-                setattr(NotifyTwitter, '_user_cache', results)
-            else:
-                getattr(NotifyTwitter, '_user_cache').update(results)
+        self._user_cache.update(results)
 
         return results
 
@@ -686,7 +668,7 @@ class NotifyTwitter(NotifyBase):
             # Determine how long we should wait for or if we should wait at
             # all. This isn't fool-proof because we can't be sure the client
             # time (calling this script) is completely synced up with the
-            # Gitter server.  One would hope we're on NTP and our clocks are
+            # Twitter server.  One would hope we're on NTP and our clocks are
             # the same allowing this to role smoothly:
 
             now = datetime.utcnow()
@@ -810,7 +792,7 @@ class NotifyTwitter(NotifyBase):
 
         return '{schema}://{ckey}/{csecret}/{akey}/{asecret}' \
             '/{targets}/?{params}'.format(
-                schema=self.secure_protocol,
+                schema=self.secure_protocol[0],
                 ckey=self.pprint(self.ckey, privacy, safe=''),
                 csecret=self.pprint(
                     self.csecret, privacy, mode=PrivacyMode.Secret, safe=''),
@@ -818,7 +800,7 @@ class NotifyTwitter(NotifyBase):
                 asecret=self.pprint(
                     self.asecret, privacy, mode=PrivacyMode.Secret, safe=''),
                 targets='/'.join(
-                    [NotifyTwitter.quote('@{}'.format(target), safe='')
+                    [NotifyTwitter.quote('@{}'.format(target), safe='@')
                      for target in self.targets]),
                 params=NotifyTwitter.urlencode(params))
 
@@ -862,6 +844,9 @@ class NotifyTwitter(NotifyBase):
             results['mode'] = \
                 NotifyTwitter.unquote(results['qsd']['mode'])
 
+        elif results['schema'].startswith('tweet'):
+            results['mode'] = TwitterMessageMode.TWEET
+
         results['targets'] = []
 
         # if a user has been defined, add it to the list of targets
