@@ -130,9 +130,14 @@ class NotifyXML(NotifyBase):
             'name': _('Payload Extras'),
             'prefix': ':',
         },
+        'params': {
+            'name': _('GET Params'),
+            'prefix': '-',
+        },
     }
 
-    def __init__(self, headers=None, method=None, payload=None, **kwargs):
+    def __init__(self, headers=None, method=None, payload=None, params=None,
+                 **kwargs):
         """
         Initialize XML Object
 
@@ -140,7 +145,7 @@ class NotifyXML(NotifyBase):
         additionally include as part of the server headers to post with
 
         """
-        super(NotifyXML, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
         self.payload = """<?xml version='1.0' encoding='utf-8'?>
 <soapenv:Envelope
@@ -167,6 +172,11 @@ class NotifyXML(NotifyBase):
             self.logger.warning(msg)
             raise TypeError(msg)
 
+        self.params = {}
+        if params:
+            # Store our extra headers
+            self.params.update(params)
+
         self.headers = {}
         if headers:
             # Store our extra headers
@@ -203,6 +213,9 @@ class NotifyXML(NotifyBase):
         # Append our headers into our parameters
         params.update({'+{}'.format(k): v for k, v in self.headers.items()})
 
+        # Append our GET params into our parameters
+        params.update({'-{}'.format(k): v for k, v in self.params.items()})
+
         # Append our payload extra's into our parameters
         params.update(
             {':{}'.format(k): v for k, v in self.payload_extras.items()})
@@ -240,7 +253,7 @@ class NotifyXML(NotifyBase):
         Perform XML Notification
         """
 
-        # prepare XML Object
+        # Prepare HTTP Headers
         headers = {
             'User-Agent': self.app_id,
             'Content-Type': 'application/xml'
@@ -417,6 +430,10 @@ class NotifyXML(NotifyBase):
         results['headers'] = {NotifyXML.unquote(x): NotifyXML.unquote(y)
                               for x, y in results['qsd+'].items()}
 
+        # Add our GET paramters in the event the user wants to pass these along
+        results['params'] = {NotifyXML.unquote(x): NotifyXML.unquote(y)
+                             for x, y in results['qsd-'].items()}
+
         # Set method if not otherwise set
         if 'method' in results['qsd'] and len(results['qsd']['method']):
             results['method'] = NotifyXML.unquote(results['qsd']['method'])
