@@ -24,4 +24,20 @@
 # THE SOFTWARE.
 import sys
 import os
+
+import pytest
+
+from apprise.common import NOTIFY_MODULE_MAP
+
 sys.path.append(os.path.join(os.path.dirname(__file__), 'helpers'))
+
+
+@pytest.fixture(scope="session", autouse=True)
+def no_throttling_everywhere(session_mocker):
+    """
+    A pytest session fixture which disables throttling on all notifiers.
+    It is automatically enabled.
+    """
+    for notifier in NOTIFY_MODULE_MAP.values():
+        plugin = notifier["plugin"]
+        session_mocker.patch.object(plugin, "request_rate_per_sec", 0)
