@@ -23,9 +23,9 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 from .rest import AppriseURLTester
-from .module import module_reload
+from .module import reload_plugin
 
 __all__ = [
     'AppriseURLTester',
-    'module_reload',
+    'reload_plugin',
 ]
