@@ -32,7 +32,7 @@ from random import choice
 from string import ascii_uppercase as str_alpha
 from string import digits as str_num
 
-from apprise import plugins
+from apprise import NotifyBase
 from apprise import NotifyType
 from apprise import Apprise
 from apprise import AppriseAsset
@@ -115,8 +115,6 @@ class AppriseURLTester:
         """
         Run a specific test
         """
-        # Disable Throttling to speed testing
-        plugins.NotifyBase.request_rate_per_sec = 0
 
         # Our expected instance
         instance = meta.get('instance', None)
@@ -229,7 +227,7 @@ class AppriseURLTester:
                 url, type(instance), str(obj)))
             assert False
 
-        if isinstance(obj, plugins.NotifyBase):
+        if isinstance(obj, NotifyBase):
             # Ensure we are not performing any type of thorttling
             obj.request_rate_per_sec = 0
 
@@ -249,6 +247,7 @@ class AppriseURLTester:
             if privacy_url:
                 # Assess that our privacy url is as expected
                 if not obj.url(privacy=True).startswith(privacy_url):
+                    print('Provided %s' % url)
                     raise AssertionError(
                         "Privacy URL: '{}' != expected '{}'".format(
                             obj.url(privacy=True)[:len(privacy_url)],
@@ -264,7 +263,7 @@ class AppriseURLTester:
 
             # Our object should be the same instance as what we had
             # originally expected above.
-            if not isinstance(obj_cmp, plugins.NotifyBase):
+            if not isinstance(obj_cmp, NotifyBase):
                 # Assert messages are hard to trace back with the
                 # way these tests work. Just printing before
                 # throwing our assertion failure makes things
@@ -387,8 +386,6 @@ class AppriseURLTester:
 
         try:
             if test_requests_exceptions is False:
-                # Disable throttling
-                obj.request_rate_per_sec = 0
 
                 # check that we're as expected
                 assert obj.notify(
@@ -472,8 +469,6 @@ class AppriseURLTester:
                         attach=attach) == attach_response
 
             else:
-                # Disable throttling
-                obj.request_rate_per_sec = 0
 
                 for _exception in self.req_exceptions:
                     mock_post.side_effect = _exception
