@@ -396,6 +396,31 @@ def test_parse_url_general():
     assert result['qsd+']['KeY'] == 'ValueA'
     assert 'kEy' in result['qsd-']
     assert result['qsd-']['kEy'] == 'ValueB'
+    assert result['qsd']['key'] == 'Value +C'
+    assert result['qsd']['+key'] == result['qsd+']['KeY']
+    assert result['qsd']['-key'] == result['qsd-']['kEy']
+
+    result = utils.parse_url(
+        'http://hostname/?+KeY=ValueA&-kEy=ValueB&KEY=Value%20+C&:colon=y',
+        plus_to_space=True)
+    assert result['schema'] == 'http'
+    assert result['host'] == 'hostname'
+    assert result['port'] is None
+    assert result['user'] is None
+    assert result['password'] is None
+    assert result['fullpath'] == '/'
+    assert result['path'] == '/'
+    assert result['query'] is None
+    assert result['url'] == 'http://hostname/'
+    assert '+key' in result['qsd']
+    assert '-key' in result['qsd']
+    assert ':colon' in result['qsd']
+    assert result['qsd:']['colon'] == 'y'
+    assert 'key' in result['qsd']
+    assert 'KeY' in result['qsd+']
+    assert result['qsd+']['KeY'] == 'ValueA'
+    assert 'kEy' in result['qsd-']
+    assert result['qsd-']['kEy'] == 'ValueB'
     assert result['qsd']['key'] == 'Value  C'
     assert result['qsd']['+key'] == result['qsd+']['KeY']
     assert result['qsd']['-key'] == result['qsd-']['kEy']
@@ -893,7 +918,7 @@ def test_parse_url_simple():
     assert '-key' in result['qsd']
     assert ':colon' in result['qsd']
     assert result['qsd'][':colon'] == 'y'
-    assert result['qsd']['key'] == 'Value  C'
+    assert result['qsd']['key'] == 'Value +C'
     assert result['qsd']['+key'] == 'ValueA'
     assert result['qsd']['-key'] == 'ValueB'
 
@@ -1361,6 +1386,30 @@ def test_is_email():
     assert utils.is_email("Just A Name") is False
     assert utils.is_email("Name <bademail>") is False
 
+    # Extended valid emails
+    #
+    # The first + denotes our label, so this test really validates
+    # that there is a correct split and parsing of our email
+    results = utils.is_email('a-z0-9_!#$%&*+/=?%`{|}~^.-@gmail.com')
+    assert '' == results['name']
+    assert 'a-z0-9_!#$%&*' == results['label']
+    assert '/=?%`{|}~^.-@gmail.com' == results['email']
+    assert 'a-z0-9_!#$%&*+/=?%`{|}~^.-@gmail.com' == results['full_email']
+    assert 'gmail.com' == results['domain']
+    assert '/=?%`{|}~^.-' == results['user']
+
+    # A similar test without '+' (use of a label)
+
+    # The first + denotes our label, so this test really validates
+    # that there is a correct split and parsing of our email
+    results = utils.is_email('a-z0-9_!#$%&*/=?%`{|}~^.-@gmail.com')
+    assert '' == results['name']
+    assert '' == results['label']
+    assert 'a-z0-9_!#$%&*/=?%`{|}~^.-@gmail.com' == results['email']
+    assert 'a-z0-9_!#$%&*/=?%`{|}~^.-@gmail.com' == results['full_email']
+    assert 'gmail.com' == results['domain']
+    assert 'a-z0-9_!#$%&*/=?%`{|}~^.-' == results['user']
+
 
 def test_is_call_sign_no():
     """
