@@ -27,11 +27,14 @@ import pytest
 from apprise.AppriseAsset import AppriseAsset
 from apprise.config.ConfigBase import ConfigBase
 from apprise import ConfigFormat
-from apprise import plugins
+from inspect import cleandoc
 import yaml
 
 # Disable logging for a cleaner testing output
 import logging
+
+from apprise.plugins.NotifyEmail import NotifyEmail
+
 logging.disable(logging.CRITICAL)
 
 
@@ -180,7 +183,7 @@ version: 1
 urls:
   - pbul://o.gn5kj6nfhv736I7jC3cj3QLRiyhgl98b
   - mailto://test:password@gmail.com
-  - syslog://:
+  - json://localhost:
       - tag: devops, admin
     """, asset=AppriseAsset())
 
@@ -504,6 +507,7 @@ urls:
     - invalid: test
   - sns://T1JJ3T3L2/:
     - invalid: test
+    - _invalid: Token can not start with an underscore
 
   # some strangeness
   -
@@ -948,12 +952,50 @@ def test_yaml_vs_text_tagging():
 
     # Now we compare our results and verify they are the same
     assert len(yaml_result) == len(text_result)
-    assert isinstance(yaml_result[0], plugins.NotifyEmail)
-    assert isinstance(text_result[0], plugins.NotifyEmail)
+    assert isinstance(yaml_result[0], NotifyEmail)
+    assert isinstance(text_result[0], NotifyEmail)
     assert 'mytag' in text_result[0]
     assert 'mytag' in yaml_result[0]
 
 
+def test_config_base_config_parse_yaml_globals():
+    """
+    API: ConfigBase.config_parse_yaml globals
+
+    """
+
+    # general reference used below
+    asset = AppriseAsset()
+
+    # Invalid Syntax (throws a ScannerError)
+    results, config = ConfigBase.config_parse_yaml(cleandoc("""
+    urls:
+      - jsons://localhost1:
+         - to: jeff@gmail.com
+           tag: jeff, customer
+           cto: 30
+           rto: 30
+           verify: no
+
+      - jsons://localhost2?cto=30&rto=30&verify=no:
+         - to: json@gmail.com
+           tag: json, customer
+    """), asset=asset)
+
+    # Invalid data gets us an empty result set
+    assert isinstance(results, list)
+
+    # Our results loaded
+    assert len(results) == 2
+    assert len(config) == 0
+
+    # Now verify that our global variables correctly initialized
+    for entry in results:
+        assert entry.verify_certificate is False
+        assert entry.socket_read_timeout == 30
+        assert entry.socket_connect_timeout == 30
+
+
 # This test fails on CentOS 8.x so it was moved into it's own function
 # so it could be bypassed. The ability to use lists in YAML files didn't
 # appear to happen until later on; it's certainly not available in v3.12
