@@ -63,7 +63,7 @@ def test_config_http(mock_post):
     # Define our good:// url
     class GoodNotification(NotifyBase):
         def __init__(self, *args, **kwargs):
-            super(GoodNotification, self).__init__(*args, **kwargs)
+            super().__init__(*args, **kwargs)
 
         def notify(self, *args, **kwargs):
             # Pretend everything is okay
