@@ -25,8 +25,8 @@
 import pytest
 from unittest import mock
 
+from apprise.plugins.NotifyBoxcar import NotifyBoxcar
 from helpers import AppriseURLTester
-from apprise import plugins
 from apprise import NotifyType
 import requests
 
@@ -58,48 +58,48 @@ apprise_url_tests = (
     }),
     # Provide both an access and a secret
     ('boxcar://%s/%s' % ('a' * 64, 'b' * 64), {
-        'instance': plugins.NotifyBoxcar,
+        'instance': NotifyBoxcar,
         'requests_response_code': requests.codes.created,
         # Our expected url(privacy=True) startswith() response:
         'privacy_url': 'boxcar://a...a/****/',
     }),
     # Test without image set
     ('boxcar://%s/%s?image=True' % ('a' * 64, 'b' * 64), {
-        'instance': plugins.NotifyBoxcar,
+        'instance': NotifyBoxcar,
         'requests_response_code': requests.codes.created,
         # don't include an image in Asset by default
         'include_image': False,
     }),
     ('boxcar://%s/%s?image=False' % ('a' * 64, 'b' * 64), {
-        'instance': plugins.NotifyBoxcar,
+        'instance': NotifyBoxcar,
         'requests_response_code': requests.codes.created,
     }),
     # our access, secret and device are all 64 characters
     # which is what we're doing here
     ('boxcar://%s/%s/@tag1/tag2///%s/?to=tag3' % (
         'a' * 64, 'b' * 64, 'd' * 64), {
-        'instance': plugins.NotifyBoxcar,
+        'instance': NotifyBoxcar,
         'requests_response_code': requests.codes.created,
     }),
     # An invalid tag
     ('boxcar://%s/%s/@%s' % ('a' * 64, 'b' * 64, 't' * 64), {
-        'instance': plugins.NotifyBoxcar,
+        'instance': NotifyBoxcar,
         'requests_response_code': requests.codes.created,
     }),
     ('boxcar://%s/%s/' % ('a' * 64, 'b' * 64), {
-        'instance': plugins.NotifyBoxcar,
+        'instance': NotifyBoxcar,
         # force a failure
         'response': False,
         'requests_response_code': requests.codes.internal_server_error,
     }),
     ('boxcar://%s/%s/' % ('a' * 64, 'b' * 64), {
-        'instance': plugins.NotifyBoxcar,
+        'instance': NotifyBoxcar,
         # throw a bizzare code forcing us to fail to look it up
         'response': False,
         'requests_response_code': 999,
     }),
     ('boxcar://%s/%s/' % ('a' * 64, 'b' * 64), {
-        'instance': plugins.NotifyBoxcar,
+        'instance': NotifyBoxcar,
         # Throws a series of connection and transfer exceptions when this flag
         # is set and tests that we gracfully handle them
         'test_requests_exceptions': True,
@@ -124,8 +124,6 @@ def test_plugin_boxcar_edge_cases(mock_post, mock_get):
     NotifyBoxcar() Edge Cases
 
     """
-    # Disable Throttling to speed testing
-    plugins.NotifyBase.request_rate_per_sec = 0
 
     # Generate some generic message types
     device = 'A' * 64
@@ -135,19 +133,19 @@ def test_plugin_boxcar_edge_cases(mock_post, mock_get):
     secret = '_' * 64
 
     # Initializes the plugin with recipients set to None
-    plugins.NotifyBoxcar(access=access, secret=secret, targets=None)
+    NotifyBoxcar(access=access, secret=secret, targets=None)
 
     # Initializes the plugin with a valid access, but invalid access key
     with pytest.raises(TypeError):
-        plugins.NotifyBoxcar(access=None, secret=secret, targets=None)
+        NotifyBoxcar(access=None, secret=secret, targets=None)
 
     # Initializes the plugin with a valid access, but invalid secret
     with pytest.raises(TypeError):
-        plugins.NotifyBoxcar(access=access, secret=None, targets=None)
+        NotifyBoxcar(access=access, secret=None, targets=None)
 
     # Initializes the plugin with recipients list
     # the below also tests our the variation of recipient types
-    plugins.NotifyBoxcar(
+    NotifyBoxcar(
         access=access, secret=secret, targets=[device, tag])
 
     mock_get.return_value = requests.Request()
@@ -156,14 +154,14 @@ def test_plugin_boxcar_edge_cases(mock_post, mock_get):
     mock_get.return_value.status_code = requests.codes.created
 
     # Test notifications without a body or a title
-    p = plugins.NotifyBoxcar(access=access, secret=secret, targets=None)
+    p = NotifyBoxcar(access=access, secret=secret, targets=None)
 
     assert p.notify(body=None, title=None, notify_type=NotifyType.INFO) is True
 
     # Test comma, separate values
     device = 'a' * 64
 
-    p = plugins.NotifyBoxcar(
+    p = NotifyBoxcar(
         access=access, secret=secret,
         targets=','.join([device, device, device]))
     assert len(p.device_tokens) == 3
