@@ -22,7 +22,7 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
-from apprise import plugins
+from apprise.plugins.NotifyD7Networks import NotifyD7Networks
 from helpers import AppriseURLTester
 
 # Disable logging for a cleaner testing output
@@ -41,20 +41,20 @@ apprise_url_tests = (
     }),
     ('d7sms://user:pass@{}/{}/{}'.format('1' * 9, '2' * 15, 'a' * 13), {
         # No valid targets to notify
-        'instance': plugins.NotifyD7Networks,
+        'instance': NotifyD7Networks,
         # Since there are no targets specified we expect a False return on
         # send()
         'notify_response': False,
     }),
     ('d7sms://user:pass@{}?batch=yes'.format('3' * 14), {
         # valid number
-        'instance': plugins.NotifyD7Networks,
+        'instance': NotifyD7Networks,
         # Our expected url(privacy=True) startswith() response:
         'privacy_url': 'd7sms://user:****@',
     }),
     ('d7sms://user:pass@{}?batch=yes'.format('7' * 14), {
         # valid number
-        'instance': plugins.NotifyD7Networks,
+        'instance': NotifyD7Networks,
         # Test what happens if a batch send fails to return a messageCount
         'requests_response_text': {
             'data': {
@@ -66,40 +66,40 @@ apprise_url_tests = (
     }),
     ('d7sms://user:pass@{}?batch=yes&to={}'.format('3' * 14, '6' * 14), {
         # valid number
-        'instance': plugins.NotifyD7Networks,
+        'instance': NotifyD7Networks,
     }),
     ('d7sms://user:pass@{}?batch=yes&from=apprise'.format('3' * 14), {
         # valid number, utilizing the optional from= variable
-        'instance': plugins.NotifyD7Networks,
+        'instance': NotifyD7Networks,
     }),
     ('d7sms://user:pass@{}?batch=yes&source=apprise'.format('3' * 14), {
         # valid number, utilizing the optional source= variable (same as from)
-        'instance': plugins.NotifyD7Networks,
+        'instance': NotifyD7Networks,
     }),
     ('d7sms://user:pass@{}?priority=invalid'.format('3' * 14), {
         # valid number; invalid priority
-        'instance': plugins.NotifyD7Networks,
+        'instance': NotifyD7Networks,
     }),
     ('d7sms://user:pass@{}?priority=3'.format('3' * 14), {
         # valid number; adjusted priority
-        'instance': plugins.NotifyD7Networks,
+        'instance': NotifyD7Networks,
     }),
     ('d7sms://user:pass@{}?priority=high'.format('3' * 14), {
         # valid number; adjusted priority (string supported)
-        'instance': plugins.NotifyD7Networks,
+        'instance': NotifyD7Networks,
     }),
     ('d7sms://user:pass@{}?batch=no'.format('3' * 14), {
         # valid number - no batch
-        'instance': plugins.NotifyD7Networks,
+        'instance': NotifyD7Networks,
     }),
     ('d7sms://user:pass@{}'.format('3' * 14), {
-        'instance': plugins.NotifyD7Networks,
+        'instance': NotifyD7Networks,
         # throw a bizzare code forcing us to fail to look it up
         'response': False,
         'requests_response_code': 999,
     }),
     ('d7sms://user:pass@{}'.format('3' * 14), {
-        'instance': plugins.NotifyD7Networks,
+        'instance': NotifyD7Networks,
         # Throws a series of connection and transfer exceptions when this flag
         # is set and tests that we gracfully handle them
         'test_requests_exceptions': True,
