@@ -30,8 +30,7 @@ from unittest import mock
 import smtplib
 from email.header import decode_header
 
-from apprise import plugins
-from apprise import NotifyType
+from apprise import NotifyType, NotifyBase
 from apprise import Apprise
 from apprise import AttachBase
 from apprise import AppriseAttachment
@@ -39,6 +38,9 @@ from apprise.plugins import NotifyEmailBase
 
 # Disable logging for a cleaner testing output
 import logging
+
+from apprise.plugins.NotifyEmail import NotifyEmail
+
 logging.disable(logging.CRITICAL)
 
 # Attachment Directory
@@ -65,120 +67,121 @@ TEST_URLS = (
 
     # Pre-Configured Email Services
     ('mailto://user:pass@gmail.com', {
-        'instance': plugins.NotifyEmail,
+        'instance': NotifyEmail,
     }),
     ('mailto://user:pass@hotmail.com', {
-        'instance': plugins.NotifyEmail,
+        'instance': NotifyEmail,
     }),
     ('mailto://user:pass@live.com', {
-        'instance': plugins.NotifyEmail,
+        'instance': NotifyEmail,
     }),
     ('mailto://user:pass@prontomail.com', {
-        'instance': plugins.NotifyEmail,
+        'instance': NotifyEmail,
     }),
     ('mailto://user:pass@yahoo.com', {
-        'instance': plugins.NotifyEmail,
+        'instance': NotifyEmail,
     }),
     ('mailto://user:pass@yahoo.ca', {
-        'instance': plugins.NotifyEmail,
+        'instance': NotifyEmail,
     }),
     ('mailto://user:pass@fastmail.com', {
-        'instance': plugins.NotifyEmail,
+        'instance': NotifyEmail,
     }),
     ('mailto://user:pass@sendgrid.com', {
-        'instance': plugins.NotifyEmail,
+        'instance': NotifyEmail,
     }),
 
     # Yandex
     ('mailto://user:pass@yandex.com', {
-        'instance': plugins.NotifyEmail,
+        'instance': NotifyEmail,
     }),
     ('mailto://user:pass@yandex.ru', {
-        'instance': plugins.NotifyEmail,
+        'instance': NotifyEmail,
     }),
     ('mailto://user:pass@yandex.fr', {
-        'instance': plugins.NotifyEmail,
+        'instance': NotifyEmail,
     }),
 
     # Custom Emails
     ('mailtos://user:pass@nuxref.com:567', {
-        'instance': plugins.NotifyEmail,
+        'instance': NotifyEmail,
     }),
     ('mailto://user:pass@nuxref.com:567?format=html', {
-        'instance': plugins.NotifyEmail,
+        'instance': NotifyEmail,
     }),
     ('mailtos://user:pass@nuxref.com:567?to=l2g@nuxref.com', {
-        'instance': plugins.NotifyEmail,
+        'instance': NotifyEmail,
     }),
     ('mailtos://user:pass@nuxref.com:567/l2g@nuxref.com', {
-        'instance': plugins.NotifyEmail,
+        'instance': NotifyEmail,
     }),
     (
         'mailto://user:pass@example.com:2525?user=l2g@example.com'
         '&pass=l2g@apprise!is!Awesome', {
-            'instance': plugins.NotifyEmail,
+            'instance': NotifyEmail,
         },
     ),
     (
         'mailto://user:pass@example.com:2525?user=l2g@example.com'
         '&pass=l2g@apprise!is!Awesome&format=text', {
-            'instance': plugins.NotifyEmail,
+            'instance': NotifyEmail,
         },
     ),
     (
         # Test Carbon Copy
         'mailtos://user:pass@example.com?smtp=smtp.example.com'
         '&name=l2g&cc=noreply@example.com,test@example.com', {
-            'instance': plugins.NotifyEmail,
+            'instance': NotifyEmail,
         },
     ),
     (
         # Test Blind Carbon Copy
         'mailtos://user:pass@example.com?smtp=smtp.example.com'
         '&name=l2g&bcc=noreply@example.com,test@example.com', {
-            'instance': plugins.NotifyEmail,
+            'instance': NotifyEmail,
         },
     ),
     (
         # Test Carbon Copy with bad email
         'mailtos://user:pass@example.com?smtp=smtp.example.com'
         '&name=l2g&cc=noreply@example.com,@', {
-            'instance': plugins.NotifyEmail,
+            'instance': NotifyEmail,
         },
     ),
     (
         # Test Blind Carbon Copy with bad email
         'mailtos://user:pass@example.com?smtp=smtp.example.com'
         '&name=l2g&bcc=noreply@example.com,@', {
-            'instance': plugins.NotifyEmail,
+            'instance': NotifyEmail,
         },
     ),
     (
         # Test Reply To
         'mailtos://user:pass@example.com?smtp=smtp.example.com'
         '&name=l2g&reply=test@example.com,test2@example.com', {
-            'instance': plugins.NotifyEmail,
+            'instance': NotifyEmail,
         },
     ),
     (
         # Test Reply To with bad email
         'mailtos://user:pass@example.com?smtp=smtp.example.com'
         '&name=l2g&reply=test@example.com,@', {
-            'instance': plugins.NotifyEmail,
+            'instance': NotifyEmail,
         },
     ),
     # headers
     ('mailto://user:pass@localhost.localdomain'
         '?+X-Customer-Campaign-ID=Apprise', {
-            'instance': plugins.NotifyEmail,
+            'instance': NotifyEmail,
         }),
     # No Password
     ('mailtos://user:@nuxref.com', {
-        'instance': plugins.NotifyEmail,
+        'instance': NotifyEmail,
     }),
-    # Invalid From Address
+    # Invalid From Address; but just gets put as the from name instead
+    # Hence the below generats From: "@ <user@nuxref.com>"
     ('mailtos://user:pass@nuxref.com?from=@', {
-        'instance': TypeError,
+        'instance': NotifyEmail,
     }),
     # Invalid From Address
     ('mailtos://nuxref.com?user=&pass=.', {
@@ -187,11 +190,11 @@ TEST_URLS = (
     # Invalid To Address is accepted, but we won't be able to properly email
     # using the notify() call
     ('mailtos://user:pass@nuxref.com?to=@', {
-        'instance': plugins.NotifyEmail,
+        'instance': NotifyEmail,
         'response': False,
     }),
     # Valid URL, but can't structure a proper email
-    ('mailtos://nuxref.com?user=%20!&pass=.', {
+    ('mailtos://nuxref.com?user=%20"&pass=.', {
         'instance': TypeError,
     }),
     # Invalid From (and To) Address
@@ -204,44 +207,48 @@ TEST_URLS = (
     }),
     # STARTTLS flag checking
     ('mailtos://user:pass@gmail.com?mode=starttls', {
-        'instance': plugins.NotifyEmail,
+        'instance': NotifyEmail,
         # Our expected url(privacy=True) startswith() response:
         'privacy_url': 'mailtos://user:****@gmail.com',
     }),
     # SSL flag checking
     ('mailtos://user:pass@gmail.com?mode=ssl', {
-        'instance': plugins.NotifyEmail,
+        'instance': NotifyEmail,
     }),
     # Can make a To address using what we have (l2g@nuxref.com)
     ('mailtos://nuxref.com?user=l2g&pass=.', {
-        'instance': plugins.NotifyEmail,
+        'instance': NotifyEmail,
         # Our expected url(privacy=True) startswith() response:
         'privacy_url': 'mailtos://l2g:****@nuxref.com',
     }),
     ('mailto://user:pass@localhost:2525', {
-        'instance': plugins.NotifyEmail,
+        'instance': NotifyEmail,
         # Throws a series of connection and transfer exceptions when this flag
         # is set and tests that we gracfully handle them
         'test_smtplib_exceptions': True,
     }),
+    # Use of both 'name' and 'from' together; these are synonymous
+    ('mailtos://user:pass@nuxref.com?'
+     'from=jack@gmail.com&name=Jason<jason@gmail.com>', {
+         'instance': NotifyEmail}),
     # Test no auth at all
     ('mailto://localhost?from=test@example.com&to=test@example.com', {
-        'instance': plugins.NotifyEmail,
+        'instance': NotifyEmail,
         'privacy_url': 'mailto://localhost',
     }),
     # Test multi-emails where some are bad
     ('mailto://user:pass@localhost/test@example.com/test2@/$@!/', {
-        'instance': plugins.NotifyEmail,
+        'instance': NotifyEmail,
         'privacy_url': 'mailto://user:****@localhost/'
     }),
     ('mailto://user:pass@localhost/?bcc=test2@,$@!/', {
-        'instance': plugins.NotifyEmail,
+        'instance': NotifyEmail,
     }),
     ('mailto://user:pass@localhost/?cc=test2@,$@!/', {
-        'instance': plugins.NotifyEmail,
+        'instance': NotifyEmail,
     }),
     ('mailto://user:pass@localhost/?reply=test2@,$@!/', {
-        'instance': plugins.NotifyEmail,
+        'instance': NotifyEmail,
     }),
 )
 
@@ -253,8 +260,6 @@ def test_plugin_email(mock_smtp, mock_smtpssl):
     NotifyEmail() General Checks
 
     """
-    # Disable Throttling to speed testing
-    plugins.NotifyBase.request_rate_per_sec = 0
 
     # iterate over our dictionary and test it out
     for (url, meta) in TEST_URLS:
@@ -321,7 +326,7 @@ def test_plugin_email(mock_smtp, mock_smtpssl):
 
             assert isinstance(obj, instance)
 
-            if isinstance(obj, plugins.NotifyBase):
+            if isinstance(obj, NotifyBase):
                 # We loaded okay; now lets make sure we can reverse this url
                 assert isinstance(obj.url(), str) is True
 
@@ -344,7 +349,7 @@ def test_plugin_email(mock_smtp, mock_smtpssl):
 
                 # Our object should be the same instance as what we had
                 # originally expected above.
-                if not isinstance(obj_cmp, plugins.NotifyBase):
+                if not isinstance(obj_cmp, NotifyBase):
                     # Assert messages are hard to trace back with the way
                     # these tests work. Just printing before throwing our
                     # assertion failure makes things easier to debug later on
@@ -432,10 +437,11 @@ def test_plugin_email_webbase_lookup(mock_smtp, mock_smtpssl):
     obj = Apprise.instantiate(
         'mailto://user:pass@l2g.com', suppress_exceptions=True)
 
-    assert isinstance(obj, plugins.NotifyEmail)
+    assert isinstance(obj, NotifyEmail)
     assert len(obj.targets) == 1
     assert (False, 'user@l2g.com') in obj.targets
-    assert obj.from_addr == 'user@l2g.com'
+    assert obj.from_addr[0] == obj.app_id
+    assert obj.from_addr[1] == 'user@l2g.com'
     assert obj.password == 'pass'
     assert obj.user == 'user'
     assert obj.secure is True
@@ -455,12 +461,10 @@ def test_plugin_email_smtplib_init_fail(mock_smtplib):
     NotifyEmail() Test exception handling when calling smtplib.SMTP()
 
     """
-    # Disable Throttling to speed testing
-    plugins.NotifyBase.request_rate_per_sec = 0
 
     obj = Apprise.instantiate(
         'mailto://user:pass@gmail.com', suppress_exceptions=False)
-    assert isinstance(obj, plugins.NotifyEmail)
+    assert isinstance(obj, NotifyEmail)
 
     # Support Exception handling of smtplib.SMTP
     mock_smtplib.side_effect = RuntimeError('Test')
@@ -480,13 +484,11 @@ def test_plugin_email_smtplib_send_okay(mock_smtplib):
     NotifyEmail() Test a successfully sent email
 
     """
-    # Disable Throttling to speed testing
-    plugins.NotifyBase.request_rate_per_sec = 0
 
     # Defaults to HTML
     obj = Apprise.instantiate(
         'mailto://user:pass@gmail.com', suppress_exceptions=False)
-    assert isinstance(obj, plugins.NotifyEmail)
+    assert isinstance(obj, NotifyEmail)
 
     # Support an email simulation where we can correctly quit
     mock_smtplib.starttls.return_value = True
@@ -500,7 +502,7 @@ def test_plugin_email_smtplib_send_okay(mock_smtplib):
     # Set Text
     obj = Apprise.instantiate(
         'mailto://user:pass@gmail.com?format=text', suppress_exceptions=False)
-    assert isinstance(obj, plugins.NotifyEmail)
+    assert isinstance(obj, NotifyEmail)
 
     assert obj.notify(
         body='body', title='test', notify_type=NotifyType.INFO) is True
@@ -542,20 +544,67 @@ def test_plugin_email_smtplib_send_okay(mock_smtplib):
     AttachBase.max_file_size = max_file_size
 
 
+@mock.patch('smtplib.SMTP')
+def test_plugin_email_smtplib_send_multiple_recipients(mock_smtplib):
+    """
+    Verify that NotifyEmail() will use a single SMTP session for submitting
+    multiple emails.
+    """
+
+    # Defaults to HTML
+    obj = Apprise.instantiate(
+        'mailto://user:pass@mail.example.org?'
+        'to=foo@example.net,bar@example.com&'
+        'cc=baz@example.org&bcc=qux@example.org', suppress_exceptions=False)
+    assert isinstance(obj, NotifyEmail)
+
+    assert obj.notify(
+        body='body', title='test', notify_type=NotifyType.INFO) is True
+
+    assert mock_smtplib.mock_calls == [
+        mock.call('mail.example.org', 25, None, timeout=15),
+        mock.call().login('user', 'pass'),
+        mock.call().sendmail(
+            'user@mail.example.org',
+            ['foo@example.net', 'baz@example.org', 'qux@example.org'],
+            mock.ANY),
+        mock.call().sendmail(
+            'user@mail.example.org',
+            ['bar@example.com', 'baz@example.org', 'qux@example.org'],
+            mock.ANY),
+        mock.call().quit(),
+    ]
+
+    # No from= used in the above
+    assert re.match(r'.*from=.*', obj.url()) is None
+    # No mode= as this isn't a secure connection
+    assert re.match(r'.*mode=.*', obj.url()) is None
+    # No smtp= as the SMTP server is the same as the hostname in this case
+    assert re.match(r'.*smtp=.*', obj.url()) is None
+    # URL is assembled based on provided user
+    assert re.match(
+        r'^mailto://user:pass\@mail.example.org/.*', obj.url()) is not None
+
+    # Verify our added emails are still part of the URL
+    assert re.match(r'.*/foo%40example.net[/?].*', obj.url()) is not None
+    assert re.match(r'.*/bar%40example.com[/?].*', obj.url()) is not None
+
+    assert re.match(r'.*bcc=qux%40example.org.*', obj.url()) is not None
+    assert re.match(r'.*cc=baz%40example.org.*', obj.url()) is not None
+
+
 @mock.patch('smtplib.SMTP')
 def test_plugin_email_smtplib_internationalization(mock_smtp):
     """
     NotifyEmail() Internationalization Handling
 
     """
-    # Disable Throttling to speed testing
-    plugins.NotifyBase.request_rate_per_sec = 0
 
     # Defaults to HTML
     obj = Apprise.instantiate(
         'mailto://user:pass@gmail.com?name=Например%20так',
         suppress_exceptions=False)
-    assert isinstance(obj, plugins.NotifyEmail)
+    assert isinstance(obj, NotifyEmail)
 
     class SMTPMock:
         def sendmail(self, *args, **kwargs):
@@ -619,7 +668,7 @@ def test_plugin_email_url_escaping():
     # So the above translates to ' %20' (a space in front of %20).  We want
     # to verify the handling of the password escaping and when it happens.
     # a very bad response would be '  ' (double space)
-    obj = plugins.NotifyEmail.parse_url(
+    obj = NotifyEmail.parse_url(
         'mailto://user:{}@gmail.com?format=text'.format(passwd))
 
     assert isinstance(obj, dict) is True
@@ -632,7 +681,7 @@ def test_plugin_email_url_escaping():
     obj = Apprise.instantiate(
         'mailto://user:{}@gmail.com?format=text'.format(passwd),
         suppress_exceptions=False)
-    assert isinstance(obj, plugins.NotifyEmail) is True
+    assert isinstance(obj, NotifyEmail) is True
 
     # The password is escaped only 'once'
     assert obj.password == ' %20'
@@ -646,15 +695,26 @@ def test_plugin_email_url_variations():
     # Test variations of username required to be an email address
     # user@example.com
     obj = Apprise.instantiate(
-        'mailto://{user}:{passwd}@example.com'.format(
+        'mailto://{user}:{passwd}@example.com?smtp=example.com'.format(
             user='apprise%40example21.ca',
             passwd='abcd123'),
         suppress_exceptions=False)
-    assert isinstance(obj, plugins.NotifyEmail) is True
+    assert isinstance(obj, NotifyEmail) is True
 
     assert obj.password == 'abcd123'
     assert obj.user == 'apprise@example21.ca'
 
+    # No from= used in the above
+    assert re.match(r'.*from=.*', obj.url()) is None
+    # No mode= as this isn't a secure connection
+    assert re.match(r'.*mode=.*', obj.url()) is None
+    # No smtp= as the SMTP server is the same as the hostname in this case
+    # even though it was explicitly specified
+    assert re.match(r'.*smtp=.*', obj.url()) is None
+    # URL is assembled based on provided user
+    assert re.match(
+        r'^mailto://apprise:abcd123\@example.com/.*', obj.url()) is not None
+
     # test username specified in the url body (as an argument)
     # this always over-rides the entry at the front of the url
     obj = Apprise.instantiate(
@@ -662,25 +722,48 @@ def test_plugin_email_url_variations():
             user='apprise%40example21.ca',
             passwd='abcd123'),
         suppress_exceptions=False)
-    assert isinstance(obj, plugins.NotifyEmail) is True
+    assert isinstance(obj, NotifyEmail) is True
 
     assert obj.password == 'abcd123'
     assert obj.user == 'apprise@example21.ca'
 
+    # No from= used in the above
+    assert re.match(r'.*from=.*', obj.url()) is None
+    # No mode= as this isn't a secure connection
+    assert re.match(r'.*mode=.*', obj.url()) is None
+    # No smtp= as the SMTP server is the same as the hostname in this case
+    assert re.match(r'.*smtp=.*', obj.url()) is None
+    # URL is assembled based on provided user
+    assert re.match(
+        r'^mailto://apprise:abcd123\@example.com/.*', obj.url()) is not None
+
     # test user and password specified in the url body (as an argument)
     # this always over-rides the entries at the front of the url
     obj = Apprise.instantiate(
-        'mailto://_:_@example.com?user={user}&pass={passwd}'.format(
+        'mailtos://_:_@example.com?user={user}&pass={passwd}'.format(
             user='apprise%40example21.ca',
             passwd='abcd123'),
         suppress_exceptions=False)
-    assert isinstance(obj, plugins.NotifyEmail) is True
+    assert isinstance(obj, NotifyEmail) is True
 
     assert obj.password == 'abcd123'
     assert obj.user == 'apprise@example21.ca'
     assert len(obj.targets) == 1
     assert (False, 'apprise@example.com') in obj.targets
-    assert obj.targets[0][1] == obj.from_addr
+    assert obj.from_addr[0] == obj.app_id
+    assert obj.from_addr[1] == 'apprise@example.com'
+    assert obj.targets[0][0] is False
+    assert obj.targets[0][1] == obj.from_addr[1]
+
+    # No from= used in the above
+    assert re.match(r'.*from=.*', obj.url()) is None
+    # Default mode is starttls
+    assert re.match(r'.*mode=starttls.*', obj.url()) is not None
+    # No smtp= as the SMTP server is the same as the hostname in this case
+    assert re.match(r'.*smtp=.*', obj.url()) is None
+    # URL is assembled based on provided user
+    assert re.match(
+        r'^mailtos://apprise:abcd123\@example.com/.*', obj.url()) is not None
 
     # test user and password specified in the url body (as an argument)
     # this always over-rides the entries at the front of the url
@@ -691,19 +774,32 @@ def test_plugin_email_url_variations():
             user='apprise%40example21.ca',
             passwd='abcd123'),
         suppress_exceptions=False)
-    assert isinstance(obj, plugins.NotifyEmail) is True
+    assert isinstance(obj, NotifyEmail) is True
 
     assert obj.password == 'abcd123'
     assert obj.user == 'apprise@example21.ca'
     assert len(obj.targets) == 1
     assert (False, 'apprise@example.com') in obj.targets
-    assert obj.targets[0][1] == obj.from_addr
+    assert obj.from_addr[0] == obj.app_id
+    assert obj.from_addr[1] == 'apprise@example.com'
+    assert obj.targets[0][0] is False
+    assert obj.targets[0][1] == obj.from_addr[1]
     assert obj.smtp_host == 'example.com'
 
+    # No from= used in the above
+    assert re.match(r'.*from=.*', obj.url()) is None
+    # No mode= as this isn't a secure connection
+    assert re.match(r'.*mode=.*', obj.url()) is None
+    # No smtp= as the SMTP server is the same as the hostname in this case
+    assert re.match(r'.*smtp=.*', obj.url()) is None
+    # URL is assembled based on provided user
+    assert re.match(
+        r'^mailto://apprise:abcd123\@example.com/.*', obj.url()) is not None
+
     # test a complicated example
     obj = Apprise.instantiate(
         'mailtos://{user}:{passwd}@{host}:{port}'
-        '?smtp={smtp_host}&format=text&from={this}&to={that}'.format(
+        '?smtp={smtp_host}&format=text&from=Charles<{this}>&to={that}'.format(
             user='apprise%40example21.ca',
             passwd='abcd123',
             host='example.com',
@@ -712,7 +808,7 @@ def test_plugin_email_url_variations():
             that='to@example.jp',
             smtp_host='smtp.example.edu'),
         suppress_exceptions=False)
-    assert isinstance(obj, plugins.NotifyEmail) is True
+    assert isinstance(obj, NotifyEmail) is True
 
     assert obj.password == 'abcd123'
     assert obj.user == 'apprise@example21.ca'
@@ -721,7 +817,28 @@ def test_plugin_email_url_variations():
     assert obj.smtp_host == 'smtp.example.edu'
     assert len(obj.targets) == 1
     assert (False, 'to@example.jp') in obj.targets
-    assert obj.from_addr == 'from@example.jp'
+    assert obj.from_addr[0] == 'Charles'
+    assert obj.from_addr[1] == 'from@example.jp'
+    assert re.match(
+        r'.*from=Charles\+%3Cfrom%40example.jp%3E.*', obj.url()) is not None
+
+    # Test Tagging under various urll encodings
+    for toaddr in ('/john.smith+mytag@domain.com',
+                   '?to=john.smith+mytag@domain.com',
+                   '/john.smith%2Bmytag@domain.com',
+                   '?to=john.smith%2Bmytag@domain.com'):
+
+        obj = Apprise.instantiate(
+            'mailto://user:pass@domain.com{}'.format(toaddr))
+        assert isinstance(obj, NotifyEmail) is True
+        assert obj.password == 'pass'
+        assert obj.user == 'user'
+        assert obj.host == 'domain.com'
+        assert obj.from_addr[0] == obj.app_id
+        assert obj.from_addr[1] == 'user@domain.com'
+        assert len(obj.targets) == 1
+        assert obj.targets[0][0] is False
+        assert obj.targets[0][1] == 'john.smith+mytag@domain.com'
 
 
 def test_plugin_email_dict_variations():
@@ -736,7 +853,7 @@ def test_plugin_email_dict_variations():
         'user': 'apprise@example.com',
         'password': 'abd123',
         'host': 'example.com'}, suppress_exceptions=False)
-    assert isinstance(obj, plugins.NotifyEmail) is True
+    assert isinstance(obj, NotifyEmail) is True
 
 
 @mock.patch('smtplib.SMTP_SSL')
@@ -747,9 +864,6 @@ def test_plugin_email_url_parsing(mock_smtp, mock_smtp_ssl):
 
     """
 
-    # Disable Throttling to speed testing
-    plugins.NotifyEmail.request_rate_per_sec = 0
-
     response = mock.Mock()
     mock_smtp_ssl.return_value = response
     mock_smtp.return_value = response
@@ -757,11 +871,11 @@ def test_plugin_email_url_parsing(mock_smtp, mock_smtp_ssl):
     # Test variations of username required to be an email address
     # user@example.com; we also test an over-ride port on a template driven
     # mailto:// entry
-    results = plugins.NotifyEmail.parse_url(
+    results = NotifyEmail.parse_url(
         'mailtos://user:pass123@hotmail.com:444'
         '?to=user2@yahoo.com&name=test%20name')
     assert isinstance(results, dict)
-    assert 'test name' == results['from_name']
+    assert 'test name' == results['from_addr']
     assert 'user' == results['user']
     assert 444 == results['port']
     assert 'hotmail.com' == results['host']
@@ -769,7 +883,7 @@ def test_plugin_email_url_parsing(mock_smtp, mock_smtp_ssl):
     assert 'user2@yahoo.com' in results['targets']
 
     obj = Apprise.instantiate(results, suppress_exceptions=False)
-    assert isinstance(obj, plugins.NotifyEmail) is True
+    assert isinstance(obj, NotifyEmail) is True
 
     assert mock_smtp.call_count == 0
     assert mock_smtp_ssl.call_count == 0
@@ -805,18 +919,18 @@ def test_plugin_email_url_parsing(mock_smtp, mock_smtp_ssl):
     # The below switches the `name` with the `to` to verify the results
     # are the same; it also verfies that the mode gets changed to SSL
     # instead of STARTTLS
-    results = plugins.NotifyEmail.parse_url(
+    results = NotifyEmail.parse_url(
         'mailtos://user:pass123@hotmail.com?smtp=override.com'
         '&name=test%20name&to=user2@yahoo.com&mode=ssl')
     assert isinstance(results, dict)
-    assert 'test name' == results['from_name']
+    assert 'test name' == results['from_addr']
     assert 'user' == results['user']
     assert 'hotmail.com' == results['host']
     assert 'pass123' == results['password']
     assert 'user2@yahoo.com' in results['targets']
     assert 'ssl' == results['secure_mode']
     obj = Apprise.instantiate(results, suppress_exceptions=False)
-    assert isinstance(obj, plugins.NotifyEmail) is True
+    assert isinstance(obj, NotifyEmail) is True
 
     assert mock_smtp.call_count == 0
     assert mock_smtp_ssl.call_count == 0
@@ -853,63 +967,97 @@ def test_plugin_email_url_parsing(mock_smtp, mock_smtp_ssl):
     #
     # Test outlook/hotmail lookups
     #
-    results = plugins.NotifyEmail.parse_url(
+    results = NotifyEmail.parse_url(
         'mailtos://user:pass123@outlook.com')
     obj = Apprise.instantiate(results, suppress_exceptions=False)
-    assert isinstance(obj, plugins.NotifyEmail) is True
-    assert obj.smtp_host == 'smtp-mail.outlook.com'
+    assert isinstance(obj, NotifyEmail) is True
+    assert obj.smtp_host == 'smtp.outlook.com'
     # No entries in the reply_to
     assert not obj.reply_to
 
-    results = plugins.NotifyEmail.parse_url(
+    results = NotifyEmail.parse_url(
         'mailtos://user:pass123@outlook.com.au')
     obj = Apprise.instantiate(results, suppress_exceptions=False)
-    assert isinstance(obj, plugins.NotifyEmail) is True
-    assert obj.smtp_host == 'smtp-mail.outlook.com'
+    assert isinstance(obj, NotifyEmail) is True
+    assert obj.smtp_host == 'smtp.outlook.com'
     # No entries in the reply_to
     assert not obj.reply_to
 
-    results = plugins.NotifyEmail.parse_url(
+    # Consisitency Checks
+    results = NotifyEmail.parse_url(
+        'mailtos://outlook.com?smtp=smtp.outlook.com'
+        '&user=user@outlook.com&pass=app.pw')
+    obj1 = Apprise.instantiate(results, suppress_exceptions=False)
+    assert isinstance(obj1, NotifyEmail) is True
+    assert obj1.smtp_host == 'smtp.outlook.com'
+    assert obj1.user == 'user@outlook.com'
+    assert obj1.password == 'app.pw'
+    assert obj1.secure_mode == 'starttls'
+    assert obj1.port == 587
+
+    results = NotifyEmail.parse_url(
+        'mailtos://user:app.pw@outlook.com')
+    obj2 = Apprise.instantiate(results, suppress_exceptions=False)
+    assert isinstance(obj2, NotifyEmail) is True
+    assert obj2.smtp_host == obj1.smtp_host
+    assert obj2.user == obj1.user
+    assert obj2.password == obj1.password
+    assert obj2.secure_mode == obj1.secure_mode
+    assert obj2.port == obj1.port
+
+    results = NotifyEmail.parse_url(
         'mailtos://user:pass123@live.com')
     obj = Apprise.instantiate(results, suppress_exceptions=False)
-    assert isinstance(obj, plugins.NotifyEmail) is True
+    assert isinstance(obj, NotifyEmail) is True
     # No entries in the reply_to
     assert not obj.reply_to
 
-    results = plugins.NotifyEmail.parse_url(
+    results = NotifyEmail.parse_url(
         'mailtos://user:pass123@hotmail.com')
     obj = Apprise.instantiate(results, suppress_exceptions=False)
-    assert isinstance(obj, plugins.NotifyEmail) is True
+    assert isinstance(obj, NotifyEmail) is True
     # No entries in the reply_to
     assert not obj.reply_to
 
     #
     # Test Port Over-Riding
     #
-    results = plugins.NotifyEmail.parse_url(
+    results = NotifyEmail.parse_url(
         "mailtos://abc:password@xyz.cn:465?"
         "smtp=smtp.exmail.qq.com&mode=ssl")
     obj = Apprise.instantiate(results, suppress_exceptions=False)
-    assert isinstance(obj, plugins.NotifyEmail) is True
+    assert isinstance(obj, NotifyEmail) is True
 
     # Verify our over-rides are in place
     assert obj.smtp_host == 'smtp.exmail.qq.com'
     assert obj.port == 465
-    assert obj.from_addr == 'abc@xyz.cn'
+    assert obj.from_addr[0] == obj.app_id
+    assert obj.from_addr[1] == 'abc@xyz.cn'
     assert obj.secure_mode == 'ssl'
     # No entries in the reply_to
     assert not obj.reply_to
 
-    results = plugins.NotifyEmail.parse_url(
+    # No from= used in the above
+    assert re.match(r'.*from=.*', obj.url()) is None
+    # No Our secure connection is SSL
+    assert re.match(r'.*mode=ssl.*', obj.url()) is not None
+    # No smtp= as the SMTP server is the same as the hostname in this case
+    assert re.match(r'.*smtp=smtp.exmail.qq.com.*', obj.url()) is not None
+    # URL is assembled based on provided user
+    assert re.match(
+        r'^mailtos://abc:password@xyz.cn:465/.*', obj.url()) is not None
+
+    results = NotifyEmail.parse_url(
         "mailtos://abc:password@xyz.cn?"
         "smtp=smtp.exmail.qq.com&mode=ssl&port=465")
     obj = Apprise.instantiate(results, suppress_exceptions=False)
-    assert isinstance(obj, plugins.NotifyEmail) is True
+    assert isinstance(obj, NotifyEmail) is True
 
     # Verify our over-rides are in place
     assert obj.smtp_host == 'smtp.exmail.qq.com'
     assert obj.port == 465
-    assert obj.from_addr == 'abc@xyz.cn'
+    assert obj.from_addr[0] == obj.app_id
+    assert obj.from_addr[1] == 'abc@xyz.cn'
     assert obj.secure_mode == 'ssl'
     # No entries in the reply_to
     assert not obj.reply_to
@@ -917,15 +1065,33 @@ def test_plugin_email_url_parsing(mock_smtp, mock_smtp_ssl):
     #
     # Test Reply-To Email
     #
-    results = plugins.NotifyEmail.parse_url(
+    results = NotifyEmail.parse_url(
         "mailtos://user:pass@example.com?reply=noreply@example.com")
     obj = Apprise.instantiate(results, suppress_exceptions=False)
-    assert isinstance(obj, plugins.NotifyEmail) is True
+    assert isinstance(obj, NotifyEmail) is True
     # Verify our over-rides are in place
     assert obj.smtp_host == 'example.com'
-    assert obj.from_addr == 'user@example.com'
+    assert obj.from_addr[0] == obj.app_id
+    assert obj.from_addr[1] == 'user@example.com'
     assert obj.secure_mode == 'starttls'
     assert obj.url().startswith(
         'mailtos://user:pass@example.com')
     # Test that our template over-ride worked
     assert 'reply=noreply%40example.com' in obj.url()
+
+    #
+    # Test Reply-To Email with Name Inline
+    #
+    results = NotifyEmail.parse_url(
+        "mailtos://user:pass@example.com?reply=Chris<noreply@example.ca>")
+    obj = Apprise.instantiate(results, suppress_exceptions=False)
+    assert isinstance(obj, NotifyEmail) is True
+    # Verify our over-rides are in place
+    assert obj.smtp_host == 'example.com'
+    assert obj.from_addr[0] == obj.app_id
+    assert obj.from_addr[1] == 'user@example.com'
+    assert obj.secure_mode == 'starttls'
+    assert obj.url().startswith(
+        'mailtos://user:pass@example.com')
+    # Test that our template over-ride worked
+    assert 'reply=Chris+%3Cnoreply%40example.ca%3E' in obj.url()
