@@ -26,8 +26,9 @@ from unittest import mock
 
 from json import dumps
 from apprise import Apprise
-from apprise import plugins
 import requests
+
+from apprise.plugins.NotifyEmby import NotifyEmby
 from helpers import AppriseURLTester
 
 # Disable logging for a cleaner testing output
@@ -54,13 +55,13 @@ apprise_url_tests = (
     }),
     # Valid Authentication
     ('emby://l2g@localhost', {
-        'instance': plugins.NotifyEmby,
+        'instance': NotifyEmby,
         # our response will be False because our authentication can't be
         # tested very well using this matrix.
         'response': False,
     }),
     ('embys://l2g:password@localhost', {
-        'instance': plugins.NotifyEmby,
+        'instance': NotifyEmby,
         # our response will be False because our authentication can't be
         # tested very well using this matrix.
         'response': False,
@@ -81,9 +82,9 @@ def test_plugin_template_urls():
     AppriseURLTester(tests=apprise_url_tests).run_all()
 
 
-@mock.patch('apprise.plugins.NotifyEmby.sessions')
-@mock.patch('apprise.plugins.NotifyEmby.login')
-@mock.patch('apprise.plugins.NotifyEmby.logout')
+@mock.patch('apprise.plugins.NotifyEmby.NotifyEmby.sessions')
+@mock.patch('apprise.plugins.NotifyEmby.NotifyEmby.login')
+@mock.patch('apprise.plugins.NotifyEmby.NotifyEmby.logout')
 @mock.patch('requests.get')
 @mock.patch('requests.post')
 def test_plugin_emby_general(mock_post, mock_get, mock_logout,
@@ -92,8 +93,6 @@ def test_plugin_emby_general(mock_post, mock_get, mock_logout,
     NotifyEmby General Tests
 
     """
-    # Disable Throttling to speed testing
-    plugins.NotifyBase.request_rate_per_sec = 0
 
     req = requests.Request()
     req.status_code = requests.codes.ok
@@ -107,14 +106,14 @@ def test_plugin_emby_general(mock_post, mock_get, mock_logout,
     mock_sessions.return_value = {'abcd': {}}
 
     obj = Apprise.instantiate('emby://l2g:l2gpass@localhost?modal=False')
-    assert isinstance(obj, plugins.NotifyEmby)
+    assert isinstance(obj, NotifyEmby)
     assert obj.notify('title', 'body', 'info') is True
     obj.access_token = 'abc'
     obj.user_id = '123'
 
     # Test Modal support
     obj = Apprise.instantiate('emby://l2g:l2gpass@localhost?modal=True')
-    assert isinstance(obj, plugins.NotifyEmby)
+    assert isinstance(obj, NotifyEmby)
     assert obj.notify('title', 'body', 'info') is True
     obj.access_token = 'abc'
     obj.user_id = '123'
@@ -168,15 +167,13 @@ def test_plugin_emby_login(mock_post, mock_get):
     NotifyEmby() login()
 
     """
-    # Disable Throttling to speed testing
-    plugins.NotifyBase.request_rate_per_sec = 0
 
     # Prepare Mock
     mock_get.return_value = requests.Request()
     mock_post.return_value = requests.Request()
 
     obj = Apprise.instantiate('emby://l2g:l2gpass@localhost')
-    assert isinstance(obj, plugins.NotifyEmby)
+    assert isinstance(obj, NotifyEmby)
 
     # Test our exception handling
     for _exception in AppriseURLTester.req_exceptions:
@@ -208,7 +205,7 @@ def test_plugin_emby_login(mock_post, mock_get):
 
     obj = Apprise.instantiate('emby://l2g:l2gpass@localhost:1234')
     # Set a different port (outside of default)
-    assert isinstance(obj, plugins.NotifyEmby)
+    assert isinstance(obj, NotifyEmby)
     assert obj.port == 1234
 
     # The login will fail because '' is not a parseable JSON response
@@ -220,7 +217,7 @@ def test_plugin_emby_login(mock_post, mock_get):
 
     # Default port assignments
     obj = Apprise.instantiate('emby://l2g:l2gpass@localhost')
-    assert isinstance(obj, plugins.NotifyEmby)
+    assert isinstance(obj, NotifyEmby)
     assert obj.port == 8096
 
     # The login will (still) fail because '' is not a parseable JSON response
@@ -233,7 +230,7 @@ def test_plugin_emby_login(mock_post, mock_get):
     mock_get.return_value.content = mock_post.return_value.content
 
     obj = Apprise.instantiate('emby://l2g:l2gpass@localhost')
-    assert isinstance(obj, plugins.NotifyEmby)
+    assert isinstance(obj, NotifyEmby)
 
     # The login will fail because the 'User' or 'Id' field wasn't parsed
     assert obj.login() is False
@@ -251,7 +248,7 @@ def test_plugin_emby_login(mock_post, mock_get):
     mock_get.return_value.content = mock_post.return_value.content
 
     obj = Apprise.instantiate('emby://l2g:l2gpass@localhost')
-    assert isinstance(obj, plugins.NotifyEmby)
+    assert isinstance(obj, NotifyEmby)
 
     # Login
     assert obj.login() is True
@@ -275,8 +272,8 @@ def test_plugin_emby_login(mock_post, mock_get):
     assert obj.access_token == '0000-0000-0000-0000'
 
 
-@mock.patch('apprise.plugins.NotifyEmby.login')
-@mock.patch('apprise.plugins.NotifyEmby.logout')
+@mock.patch('apprise.plugins.NotifyEmby.NotifyEmby.login')
+@mock.patch('apprise.plugins.NotifyEmby.NotifyEmby.logout')
 @mock.patch('requests.get')
 @mock.patch('requests.post')
 def test_plugin_emby_sessions(mock_post, mock_get, mock_logout, mock_login):
@@ -284,8 +281,6 @@ def test_plugin_emby_sessions(mock_post, mock_get, mock_logout, mock_login):
     NotifyEmby() sessions()
 
     """
-    # Disable Throttling to speed testing
-    plugins.NotifyBase.request_rate_per_sec = 0
 
     # Prepare Mock
     mock_get.return_value = requests.Request()
@@ -296,7 +291,7 @@ def test_plugin_emby_sessions(mock_post, mock_get, mock_logout, mock_login):
     mock_logout.return_value = True
 
     obj = Apprise.instantiate('emby://l2g:l2gpass@localhost')
-    assert isinstance(obj, plugins.NotifyEmby)
+    assert isinstance(obj, NotifyEmby)
     obj.access_token = 'abc'
     obj.user_id = '123'
 
@@ -373,7 +368,7 @@ def test_plugin_emby_sessions(mock_post, mock_get, mock_logout, mock_login):
     assert len(sessions) == 0
 
 
-@mock.patch('apprise.plugins.NotifyEmby.login')
+@mock.patch('apprise.plugins.NotifyEmby.NotifyEmby.login')
 @mock.patch('requests.get')
 @mock.patch('requests.post')
 def test_plugin_emby_logout(mock_post, mock_get, mock_login):
@@ -381,8 +376,6 @@ def test_plugin_emby_logout(mock_post, mock_get, mock_login):
     NotifyEmby() logout()
 
     """
-    # Disable Throttling to speed testing
-    plugins.NotifyBase.request_rate_per_sec = 0
 
     # Prepare Mock
     mock_get.return_value = requests.Request()
@@ -392,7 +385,7 @@ def test_plugin_emby_logout(mock_post, mock_get, mock_login):
     mock_login.return_value = True
 
     obj = Apprise.instantiate('emby://l2g:l2gpass@localhost')
-    assert isinstance(obj, plugins.NotifyEmby)
+    assert isinstance(obj, NotifyEmby)
     obj.access_token = 'abc'
     obj.user_id = '123'
 
