@@ -26,8 +26,8 @@
 from unittest import mock
 
 import requests
-from apprise import plugins
 from apprise import Apprise
+from apprise.plugins.NotifyHomeAssistant import NotifyHomeAssistant
 from helpers import AppriseURLTester
 
 # Disable logging for a cleaner testing output
@@ -50,19 +50,19 @@ apprise_url_tests = (
         'instance': TypeError,
     }),
     ('hassio://localhost/long-lived-access-token', {
-        'instance': plugins.NotifyHomeAssistant,
+        'instance': NotifyHomeAssistant,
     }),
     ('hassio://user:pass@localhost/long-lived-access-token/', {
-        'instance': plugins.NotifyHomeAssistant,
+        'instance': NotifyHomeAssistant,
 
         # Our expected url(privacy=True) startswith() response:
         'privacy_url': 'hassio://user:****@localhost/l...n',
     }),
     ('hassio://localhost:80/long-lived-access-token', {
-        'instance': plugins.NotifyHomeAssistant,
+        'instance': NotifyHomeAssistant,
     }),
     ('hassio://user@localhost:8123/llat', {
-        'instance': plugins.NotifyHomeAssistant,
+        'instance': NotifyHomeAssistant,
         'privacy_url': 'hassio://user@localhost/l...t',
     }),
     ('hassios://localhost/llat?nid=!%', {
@@ -71,41 +71,41 @@ apprise_url_tests = (
     }),
     ('hassios://localhost/llat?nid=abcd', {
         # Valid notification_id
-        'instance': plugins.NotifyHomeAssistant,
+        'instance': NotifyHomeAssistant,
     }),
     ('hassios://user:pass@localhost/llat', {
-        'instance': plugins.NotifyHomeAssistant,
+        'instance': NotifyHomeAssistant,
         'privacy_url': 'hassios://user:****@localhost/l...t',
     }),
     ('hassios://localhost:8443/path/llat/', {
-        'instance': plugins.NotifyHomeAssistant,
+        'instance': NotifyHomeAssistant,
         'privacy_url': 'hassios://localhost:8443/path/l...t',
     }),
     ('hassio://localhost:8123/a/path?accesstoken=llat', {
-        'instance': plugins.NotifyHomeAssistant,
+        'instance': NotifyHomeAssistant,
         # Default port; so it's stripped off
         # accesstoken was specified as kwarg
         'privacy_url': 'hassio://localhost/a/path/l...t',
     }),
     ('hassios://user:password@localhost:80/llat/', {
-        'instance': plugins.NotifyHomeAssistant,
+        'instance': NotifyHomeAssistant,
 
         'privacy_url': 'hassios://user:****@localhost:80',
     }),
     ('hassio://user:pass@localhost:8123/llat', {
-        'instance': plugins.NotifyHomeAssistant,
+        'instance': NotifyHomeAssistant,
         # force a failure
         'response': False,
         'requests_response_code': requests.codes.internal_server_error,
     }),
     ('hassio://user:pass@localhost/llat', {
-        'instance': plugins.NotifyHomeAssistant,
+        'instance': NotifyHomeAssistant,
         # throw a bizzare code forcing us to fail to look it up
         'response': False,
         'requests_response_code': 999,
     }),
     ('hassio://user:pass@localhost/llat', {
-        'instance': plugins.NotifyHomeAssistant,
+        'instance': NotifyHomeAssistant,
         # Throws a series of connection and transfer exceptions when this flag
         # is set and tests that we gracfully handle them
         'test_requests_exceptions': True,
@@ -129,8 +129,6 @@ def test_plugin_homeassistant_general(mock_post):
     NotifyHomeAssistant() General Checks
 
     """
-    # Disable Throttling to speed testing
-    plugins.NotifyBase.request_rate_per_sec = 0
 
     response = mock.Mock()
     response.content = ''
@@ -141,7 +139,7 @@ def test_plugin_homeassistant_general(mock_post):
 
     # Variation Initializations
     obj = Apprise.instantiate('hassio://localhost/accesstoken')
-    assert isinstance(obj, plugins.NotifyHomeAssistant) is True
+    assert isinstance(obj, NotifyHomeAssistant) is True
     assert isinstance(obj.url(), str) is True
 
     # Send Notification
