@@ -27,10 +27,9 @@ from unittest import mock
 import pytest
 import requests
 import apprise
-from apprise import plugins
 from apprise import NotifyType
 from helpers import AppriseURLTester
-from apprise.plugins.NotifyJoin import JoinPriority
+from apprise.plugins.NotifyJoin import JoinPriority, NotifyJoin
 
 # Disable logging for a cleaner testing output
 import logging
@@ -47,69 +46,69 @@ apprise_url_tests = (
     }),
     # APIkey; no device
     ('join://%s' % ('a' * 32), {
-        'instance': plugins.NotifyJoin,
+        'instance': NotifyJoin,
     }),
     # API Key + device (using to=)
     ('join://%s?to=%s' % ('a' * 32, 'd' * 32), {
-        'instance': plugins.NotifyJoin,
+        'instance': NotifyJoin,
 
         # Our expected url(privacy=True) startswith() response:
         'privacy_url': 'join://a...a/',
     }),
     # API Key + priority setting
     ('join://%s?priority=high' % ('a' * 32), {
-        'instance': plugins.NotifyJoin,
+        'instance': NotifyJoin,
     }),
     # API Key + invalid priority setting
     ('join://%s?priority=invalid' % ('a' * 32), {
-        'instance': plugins.NotifyJoin,
+        'instance': NotifyJoin,
     }),
     # API Key + priority setting (empty)
     ('join://%s?priority=' % ('a' * 32), {
-        'instance': plugins.NotifyJoin,
+        'instance': NotifyJoin,
     }),
     # API Key + device
     ('join://%s@%s?image=True' % ('a' * 32, 'd' * 32), {
-        'instance': plugins.NotifyJoin,
+        'instance': NotifyJoin,
     }),
     # No image
     ('join://%s@%s?image=False' % ('a' * 32, 'd' * 32), {
-        'instance': plugins.NotifyJoin,
+        'instance': NotifyJoin,
     }),
     # API Key + Device Name
     ('join://%s/%s' % ('a' * 32, 'My Device'), {
-        'instance': plugins.NotifyJoin,
+        'instance': NotifyJoin,
     }),
     # API Key + device
     ('join://%s/%s' % ('a' * 32, 'd' * 32), {
-        'instance': plugins.NotifyJoin,
+        'instance': NotifyJoin,
         # don't include an image by default
         'include_image': False,
     }),
     # API Key + 2 devices
     ('join://%s/%s/%s' % ('a' * 32, 'd' * 32, 'e' * 32), {
-        'instance': plugins.NotifyJoin,
+        'instance': NotifyJoin,
         # don't include an image by default
         'include_image': False,
     }),
     # API Key + 1 device and 1 group
     ('join://%s/%s/%s' % ('a' * 32, 'd' * 32, 'group.chrome'), {
-        'instance': plugins.NotifyJoin,
+        'instance': NotifyJoin,
     }),
     ('join://%s' % ('a' * 32), {
-        'instance': plugins.NotifyJoin,
+        'instance': NotifyJoin,
         # force a failure
         'response': False,
         'requests_response_code': requests.codes.internal_server_error,
     }),
     ('join://%s' % ('a' * 32), {
-        'instance': plugins.NotifyJoin,
+        'instance': NotifyJoin,
         # throw a bizzare code forcing us to fail to look it up
         'response': False,
         'requests_response_code': 999,
     }),
     ('join://%s' % ('a' * 32), {
-        'instance': plugins.NotifyJoin,
+        'instance': NotifyJoin,
         # Throws a series of connection and transfer exceptions when this flag
         # is set and tests that we gracfully handle them
         'test_requests_exceptions': True,
@@ -134,8 +133,6 @@ def test_plugin_join_edge_cases(mock_post, mock_get):
     NotifyJoin() Edge Cases
 
     """
-    # Disable Throttling to speed testing
-    plugins.NotifyBase.request_rate_per_sec = 0
 
     # Generate some generic message types
     device = 'A' * 32
@@ -143,21 +140,21 @@ def test_plugin_join_edge_cases(mock_post, mock_get):
     apikey = 'a' * 32
 
     # Initializes the plugin with devices set to a string
-    plugins.NotifyJoin(apikey=apikey, targets=group)
+    NotifyJoin(apikey=apikey, targets=group)
 
     # Initializes the plugin with devices set to None
-    plugins.NotifyJoin(apikey=apikey, targets=None)
+    NotifyJoin(apikey=apikey, targets=None)
 
     # Initializes the plugin with an invalid apikey
     with pytest.raises(TypeError):
-        plugins.NotifyJoin(apikey=None)
+        NotifyJoin(apikey=None)
 
     # Whitespace also acts as an invalid apikey
     with pytest.raises(TypeError):
-        plugins.NotifyJoin(apikey="   ")
+        NotifyJoin(apikey="   ")
 
     # Initializes the plugin with devices set to a set
-    p = plugins.NotifyJoin(apikey=apikey, targets=[group, device])
+    p = NotifyJoin(apikey=apikey, targets=[group, device])
 
     # Prepare our mock responses
     req = requests.Request()
@@ -199,9 +196,6 @@ def test_plugin_join_config_files(mock_post):
             tag: join_str emerg
     """ % ('a' * 32, 'b' * 32, 'c' * 32, 'd' * 32)
 
-    # Disable Throttling to speed testing
-    plugins.NotifyJoin.request_rate_per_sec = 0
-
     # Prepare Mock
     mock_post.return_value = requests.Request()
     mock_post.return_value.status_code = requests.codes.ok
