@@ -27,8 +27,9 @@ import os
 from unittest import mock
 
 import requests
+
+from apprise.plugins.NotifyMailgun import NotifyMailgun
 from helpers import AppriseURLTester
-from apprise import plugins
 from apprise import Apprise
 from apprise import AppriseAttachment
 from apprise import NotifyType
@@ -58,78 +59,90 @@ apprise_url_tests = (
         'instance': TypeError,
     }),
     # Invalid from email address
-    ('mailgun://!@localhost.localdomain/{}-{}-{}'.format(
+    ('mailgun://"@localhost.localdomain/{}-{}-{}'.format(
         'a' * 32, 'b' * 8, 'c' * 8), {
         'instance': TypeError,
     }),
     # No To email address, but everything else is valid
     ('mailgun://user@localhost.localdomain/{}-{}-{}'.format(
         'a' * 32, 'b' * 8, 'c' * 8), {
-        'instance': plugins.NotifyMailgun,
+        'instance': NotifyMailgun,
     }),
     ('mailgun://user@localhost.localdomain/{}-{}-{}?format=markdown'.format(
         'a' * 32, 'b' * 8, 'c' * 8), {
-        'instance': plugins.NotifyMailgun,
+        'instance': NotifyMailgun,
     }),
     ('mailgun://user@localhost.localdomain/{}-{}-{}?format=html'.format(
         'a' * 32, 'b' * 8, 'c' * 8), {
-        'instance': plugins.NotifyMailgun,
+        'instance': NotifyMailgun,
     }),
     ('mailgun://user@localhost.localdomain/{}-{}-{}?format=text'.format(
         'a' * 32, 'b' * 8, 'c' * 8), {
-        'instance': plugins.NotifyMailgun,
+        'instance': NotifyMailgun,
     }),
     # valid url with region specified (case insensitve)
     ('mailgun://user@localhost.localdomain/{}-{}-{}?region=uS'.format(
         'a' * 32, 'b' * 8, 'c' * 8), {
-            'instance': plugins.NotifyMailgun,
+            'instance': NotifyMailgun,
     }),
     # valid url with region specified (case insensitve)
     ('mailgun://user@localhost.localdomain/{}-{}-{}?region=EU'.format(
         'a' * 32, 'b' * 8, 'c' * 8), {
-            'instance': plugins.NotifyMailgun,
+            'instance': NotifyMailgun,
     }),
     # invalid url with region specified (case insensitve)
     ('mailgun://user@localhost.localdomain/{}-{}-{}?region=invalid'.format(
         'a' * 32, 'b' * 8, 'c' * 8), {
             'instance': TypeError,
     }),
+    # Use of both 'name' and 'from' together; these are synonymous
+    ('mailgun://user@localhost.localdomain/{}-{}-{}?'
+     'from=jack@gmail.com&name=Jason<jason@gmail.com>'.format(
+         'a' * 32, 'b' * 8, 'c' * 8), {
+             'instance': NotifyMailgun}),
+
     # headers
     ('mailgun://user@localhost.localdomain/{}-{}-{}'
         '?+X-Customer-Campaign-ID=Apprise'.format(
             'a' * 32, 'b' * 8, 'c' * 8), {
-                'instance': plugins.NotifyMailgun,
+                'instance': NotifyMailgun,
         }),
     # template tokens
     ('mailgun://user@localhost.localdomain/{}-{}-{}'
         '?:name=Chris&:status=admin'.format(
             'a' * 32, 'b' * 8, 'c' * 8), {
-                'instance': plugins.NotifyMailgun,
+                'instance': NotifyMailgun,
+        }),
+    # We can use the `from=` directive as well:
+    ('mailgun://user@localhost.localdomain/{}-{}-{}'
+        '?:from=Chris&:status=admin'.format(
+            'a' * 32, 'b' * 8, 'c' * 8), {
+                'instance': NotifyMailgun,
         }),
     # bcc and cc
     ('mailgun://user@localhost.localdomain/{}-{}-{}'
         '?bcc=user@example.com&cc=user2@example.com'.format(
             'a' * 32, 'b' * 8, 'c' * 8), {
-                'instance': plugins.NotifyMailgun,
+                'instance': NotifyMailgun,
         }),
     # One To Email address
     ('mailgun://user@localhost.localdomain/{}-{}-{}/test@example.com'.format(
         'a' * 32, 'b' * 8, 'c' * 8), {
-            'instance': plugins.NotifyMailgun,
+            'instance': NotifyMailgun,
     }),
     ('mailgun://user@localhost.localdomain/'
         '{}-{}-{}?to=test@example.com'.format(
             'a' * 32, 'b' * 8, 'c' * 8), {
-                'instance': plugins.NotifyMailgun}),
+                'instance': NotifyMailgun}),
     # One To Email address, a from name specified too
     ('mailgun://user@localhost.localdomain/{}-{}-{}/'
         'test@example.com?name="Frodo"'.format(
             'a' * 32, 'b' * 8, 'c' * 8), {
-                'instance': plugins.NotifyMailgun}),
+                'instance': NotifyMailgun}),
     # Invalid 'To' Email address
     ('mailgun://user@localhost.localdomain/{}-{}-{}/invalid'.format(
         'a' * 32, 'b' * 8, 'c' * 8), {
-            'instance': plugins.NotifyMailgun,
+            'instance': NotifyMailgun,
             # Expected notify() response
             'notify_response': False,
     }),
@@ -139,25 +152,25 @@ apprise_url_tests = (
         '/'.join(('user1@example.com', 'invalid', 'User2:user2@example.com')),
         ','.join(('user3@example.com', 'i@v', 'User1:user1@example.com')),
         ','.join(('user4@example.com', 'g@r@b', 'Da:user5@example.com'))), {
-            'instance': plugins.NotifyMailgun,
+            'instance': NotifyMailgun,
     }),
     ('mailgun://user@localhost.localdomain/{}-{}-{}'.format(
         'a' * 32, 'b' * 8, 'c' * 8), {
-        'instance': plugins.NotifyMailgun,
+        'instance': NotifyMailgun,
         # force a failure
         'response': False,
         'requests_response_code': requests.codes.internal_server_error,
     }),
     ('mailgun://user@localhost.localdomain/{}-{}-{}'.format(
         'a' * 32, 'b' * 8, 'c' * 8), {
-        'instance': plugins.NotifyMailgun,
+        'instance': NotifyMailgun,
         # throw a bizzare code forcing us to fail to look it up
         'response': False,
         'requests_response_code': 999,
     }),
     ('mailgun://user@localhost.localdomain/{}-{}-{}'.format(
         'a' * 32, 'b' * 8, 'c' * 8), {
-        'instance': plugins.NotifyMailgun,
+        'instance': NotifyMailgun,
         # Throws a series of connection and transfer exceptions when this flag
         # is set and tests that we gracfully handle them
         'test_requests_exceptions': True,
@@ -181,8 +194,6 @@ def test_plugin_mailgun_attachments(mock_post):
     NotifyMailgun() Attachments
 
     """
-    # Disable Throttling to speed testing
-    plugins.NotifyBase.request_rate_per_sec = 0
 
     okay_response = requests.Request()
     okay_response.status_code = requests.codes.ok
@@ -196,7 +207,7 @@ def test_plugin_mailgun_attachments(mock_post):
 
     obj = Apprise.instantiate(
         'mailgun://user@localhost.localdomain/{}'.format(apikey))
-    assert isinstance(obj, plugins.NotifyMailgun)
+    assert isinstance(obj, NotifyMailgun)
 
     # Test Valid Attachment
     path = os.path.join(TEST_VAR_DIR, 'apprise-test.gif')
@@ -268,7 +279,7 @@ def test_plugin_mailgun_attachments(mock_post):
     obj = Apprise.instantiate(
         'mailgun://no-reply@example.com/{}/'
         'user1@example.com/user2@example.com?batch=yes'.format(apikey))
-    assert isinstance(obj, plugins.NotifyMailgun)
+    assert isinstance(obj, NotifyMailgun)
 
     # Force our batch to break into separate messages
     obj.default_batch_size = 1
@@ -289,3 +300,113 @@ def test_plugin_mailgun_attachments(mock_post):
         body='body', title='title', notify_type=NotifyType.INFO,
         attach=attach) is True
     assert mock_post.call_count == 1
+
+
+@mock.patch('requests.post')
+def test_plugin_mailgun_header_check(mock_post):
+    """
+    NotifyMailgun() Test Header Prep
+
+    """
+
+    okay_response = requests.Request()
+    okay_response.status_code = requests.codes.ok
+    okay_response.content = ""
+
+    # Assign our mock object our return value
+    mock_post.return_value = okay_response
+
+    # API Key
+    apikey = 'abc123'
+
+    obj = Apprise.instantiate(
+        'mailgun://user@localhost.localdomain/{}'.format(apikey))
+    assert isinstance(obj, NotifyMailgun)
+    assert isinstance(obj.url(), str) is True
+
+    # No calls made yet
+    assert mock_post.call_count == 0
+
+    # Send our notification
+    assert obj.notify(
+        body='body', title='title', notify_type=NotifyType.INFO) is True
+
+    # 2 calls were made, one to perform an email lookup, the second
+    # was the notification itself
+    assert mock_post.call_count == 1
+    assert mock_post.call_args_list[0][0][0] == \
+        'https://api.mailgun.net/v3/localhost.localdomain/messages'
+
+    payload = mock_post.call_args_list[0][1]['data']
+    assert 'from' in payload
+    assert 'Apprise <user@localhost.localdomain>' == payload['from']
+    assert 'user@localhost.localdomain' == payload['to']
+
+    # Reset our mock object
+    mock_post.reset_mock()
+
+    obj = Apprise.instantiate(
+        'mailgun://user@localhost.localdomain/'
+        '{}?from=Luke%20Skywalker'.format(apikey))
+    assert isinstance(obj, NotifyMailgun)
+    assert isinstance(obj.url(), str) is True
+
+    # No calls made yet
+    assert mock_post.call_count == 0
+
+    # Send our notification
+    assert obj.notify(
+        body='body', title='title', notify_type=NotifyType.INFO) is True
+
+    assert mock_post.call_count == 1
+    payload = mock_post.call_args_list[0][1]['data']
+    assert 'from' in payload
+    assert 'to' in payload
+    assert 'Luke Skywalker <user@localhost.localdomain>' == payload['from']
+    assert 'user@localhost.localdomain' == payload['to']
+
+    # Reset our mock object
+    mock_post.reset_mock()
+
+    obj = Apprise.instantiate(
+        'mailgun://user@localhost.localdomain/{}'
+        '?from=Luke%20Skywalker<luke@rebels.com>'.format(apikey))
+    assert isinstance(obj, NotifyMailgun)
+    assert isinstance(obj.url(), str) is True
+
+    # No calls made yet
+    assert mock_post.call_count == 0
+
+    # Send our notification
+    assert obj.notify(
+        body='body', title='title', notify_type=NotifyType.INFO) is True
+
+    assert mock_post.call_count == 1
+    payload = mock_post.call_args_list[0][1]['data']
+    assert 'from' in payload
+    assert 'to' in payload
+    assert 'Luke Skywalker <luke@rebels.com>' == payload['from']
+    assert 'luke@rebels.com' == payload['to']
+
+    # Reset our mock object
+    mock_post.reset_mock()
+
+    obj = Apprise.instantiate(
+        'mailgun://user@localhost.localdomain/{}'
+        '?from=luke@rebels.com'.format(apikey))
+    assert isinstance(obj, NotifyMailgun)
+    assert isinstance(obj.url(), str) is True
+
+    # No calls made yet
+    assert mock_post.call_count == 0
+
+    # Send our notification
+    assert obj.notify(
+        body='body', title='title', notify_type=NotifyType.INFO) is True
+
+    assert mock_post.call_count == 1
+    payload = mock_post.call_args_list[0][1]['data']
+    assert 'from' in payload
+    assert 'to' in payload
+    assert 'luke@rebels.com' == payload['from']
+    assert 'luke@rebels.com' == payload['to']
