@@ -23,7 +23,8 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 import requests
-from apprise import plugins
+
+from apprise.plugins.NotifyNotica import NotifyNotica
 from helpers import AppriseURLTester
 
 # Disable logging for a cleaner testing output
@@ -40,90 +41,90 @@ apprise_url_tests = (
     }),
     # Native URL
     ('https://notica.us/?%s' % ('z' * 6), {
-        'instance': plugins.NotifyNotica,
+        'instance': NotifyNotica,
 
         # Our expected url(privacy=True) startswith() response:
         'privacy_url': 'notica://z...z/',
     }),
     # Native URL with additional arguments
     ('https://notica.us/?%s&overflow=upstream' % ('z' * 6), {
-        'instance': plugins.NotifyNotica,
+        'instance': NotifyNotica,
 
         # Our expected url(privacy=True) startswith() response:
         'privacy_url': 'notica://z...z/',
     }),
     # Token specified
     ('notica://%s' % ('a' * 6), {
-        'instance': plugins.NotifyNotica,
+        'instance': NotifyNotica,
 
         # Our expected url(privacy=True) startswith() response:
         'privacy_url': 'notica://a...a/',
     }),
     # Self-Hosted configuration
     ('notica://localhost/%s' % ('b' * 6), {
-        'instance': plugins.NotifyNotica,
+        'instance': NotifyNotica,
     }),
     ('notica://user@localhost/%s' % ('c' * 6), {
-        'instance': plugins.NotifyNotica,
+        'instance': NotifyNotica,
     }),
     ('notica://user:pass@localhost/%s/' % ('d' * 6), {
-        'instance': plugins.NotifyNotica,
+        'instance': NotifyNotica,
 
         # Our expected url(privacy=True) startswith() response:
         'privacy_url': 'notica://user:****@localhost/d...d',
     }),
     ('notica://user:pass@localhost/a/path/%s/' % ('r' * 6), {
-        'instance': plugins.NotifyNotica,
+        'instance': NotifyNotica,
 
         # Our expected url(privacy=True) startswith() response:
         'privacy_url': 'notica://user:****@localhost/a/path/r...r',
     }),
     ('notica://localhost:8080/%s' % ('a' * 6), {
-        'instance': plugins.NotifyNotica,
+        'instance': NotifyNotica,
     }),
     ('notica://user:pass@localhost:8080/%s' % ('b' * 6), {
-        'instance': plugins.NotifyNotica,
+        'instance': NotifyNotica,
     }),
     ('noticas://localhost/%s' % ('j' * 6), {
-        'instance': plugins.NotifyNotica,
+        'instance': NotifyNotica,
         'privacy_url': 'noticas://localhost/j...j',
     }),
     ('noticas://user:pass@localhost/%s' % ('e' * 6), {
-        'instance': plugins.NotifyNotica,
+        'instance': NotifyNotica,
 
         # Our expected url(privacy=True) startswith() response:
         'privacy_url': 'noticas://user:****@localhost/e...e',
     }),
     ('noticas://localhost:8080/path/%s' % ('5' * 6), {
-        'instance': plugins.NotifyNotica,
+        'instance': NotifyNotica,
         'privacy_url': 'noticas://localhost:8080/path/5...5',
     }),
     ('noticas://user:pass@localhost:8080/%s' % ('6' * 6), {
-        'instance': plugins.NotifyNotica,
+        'instance': NotifyNotica,
     }),
     ('notica://%s' % ('b' * 6), {
-        'instance': plugins.NotifyNotica,
+        'instance': NotifyNotica,
         # don't include an image by default
         'include_image': False,
     }),
     # Test Header overrides
     ('notica://localhost:8080//%s/?+HeaderKey=HeaderValue' % ('7' * 6), {
-        'instance': plugins.NotifyNotica,
+        'instance': NotifyNotica,
     }),
     ('notica://%s' % ('c' * 6), {
-        'instance': plugins.NotifyNotica,
+        'instance': NotifyNotica,
         # force a failure
         'response': False,
         'requests_response_code': requests.codes.internal_server_error,
     }),
     ('notica://%s' % ('d' * 7), {
-        'instance': plugins.NotifyNotica,
+        'instance': NotifyNotica,
         # throw a bizzare code forcing us to fail to look it up
         'response': False,
         'requests_response_code': 999,
     }),
     ('notica://%s' % ('e' * 8), {
-        'instance': plugins.NotifyNotica,
+        'instance': NotifyNotica,
         # Throws a series of connection and transfer exceptions when this flag
         # is set and tests that we gracfully handle them
         'test_requests_exceptions': True,
