@@ -23,7 +23,8 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 import requests
-from apprise import plugins
+
+from apprise.plugins.NotifyParsePlatform import NotifyParsePlatform
 from helpers import AppriseURLTester
 
 # Disable logging for a cleaner testing output
@@ -53,14 +54,14 @@ apprise_url_tests = (
     }),
     # app_id + master_key (using arguments=)
     ('parseps://localhost?app_id=%s&master_key=%s' % ('a' * 32, 'd' * 32), {
-        'instance': plugins.NotifyParsePlatform,
+        'instance': NotifyParsePlatform,
 
         # Our expected url(privacy=True) startswith() response:
         'privacy_url': 'parseps://a...a:d...d@localhost',
     }),
     # Set a device id + custom port
     ('parsep://app_id:master_key@localhost:8080?device=ios', {
-        'instance': plugins.NotifyParsePlatform,
+        'instance': NotifyParsePlatform,
     }),
     # invalid device id
     ('parsep://app_id:master_key@localhost?device=invalid', {
@@ -68,22 +69,22 @@ apprise_url_tests = (
     }),
     # Normal Query
     ('parseps://app_id:master_key@localhost', {
-        'instance': plugins.NotifyParsePlatform,
+        'instance': NotifyParsePlatform,
     }),
     ('parseps://app_id:master_key@localhost', {
-        'instance': plugins.NotifyParsePlatform,
+        'instance': NotifyParsePlatform,
         # force a failure
         'response': False,
         'requests_response_code': requests.codes.internal_server_error,
     }),
     ('parseps://app_id:master_key@localhost', {
-        'instance': plugins.NotifyParsePlatform,
+        'instance': NotifyParsePlatform,
         # throw a bizzare code forcing us to fail to look it up
         'response': False,
         'requests_response_code': 999,
     }),
     ('parseps://app_id:master_key@localhost', {
-        'instance': plugins.NotifyParsePlatform,
+        'instance': NotifyParsePlatform,
         # Throws a series of connection and transfer exceptions when this flag
         # is set and tests that we gracfully handle them
         'test_requests_exceptions': True,
