@@ -24,8 +24,8 @@
 # THE SOFTWARE.
 import pytest
 import requests
-from apprise import plugins
 from apprise import NotifyType
+from apprise.plugins.NotifyRocketChat import NotifyRocketChat
 from helpers import AppriseURLTester
 from unittest import mock
 
@@ -66,7 +66,7 @@ apprise_url_tests = (
     }),
     # A room and port identifier
     ('rocket://user:pass@localhost:8080/room/', {
-        'instance': plugins.NotifyRocketChat,
+        'instance': NotifyRocketChat,
         # The response text is expected to be the following on a success
         'requests_response_text': {
             'status': 'success',
@@ -75,10 +75,11 @@ apprise_url_tests = (
                 'userId': 'user',
             },
         },
+        'privacy_url': 'rocket://user:****@localhost',
     }),
     # A channel (using the to=)
     ('rockets://user:pass@localhost?to=#channel', {
-        'instance': plugins.NotifyRocketChat,
+        'instance': NotifyRocketChat,
         # The response text is expected to be the following on a success
         'requests_response_text': {
             'status': 'success',
@@ -87,10 +88,11 @@ apprise_url_tests = (
                 'userId': 'user',
             },
         },
+        'privacy_url': 'rockets://user:****@localhost',
     }),
     # A channel
     ('rockets://user:pass@localhost/#channel', {
-        'instance': plugins.NotifyRocketChat,
+        'instance': NotifyRocketChat,
         # The response text is expected to be the following on a success
         'requests_response_text': {
             'status': 'success',
@@ -99,10 +101,11 @@ apprise_url_tests = (
                 'userId': 'user',
             },
         },
+        'privacy_url': 'rockets://user:****@localhost',
     }),
     # Several channels
     ('rocket://user:pass@localhost/#channel1/#channel2/?avatar=Yes', {
-        'instance': plugins.NotifyRocketChat,
+        'instance': NotifyRocketChat,
         # The response text is expected to be the following on a success
         'requests_response_text': {
             'status': 'success',
@@ -111,10 +114,11 @@ apprise_url_tests = (
                 'userId': 'user',
             },
         },
+        'privacy_url': 'rocket://user:****@localhost',
     }),
     # Several Rooms
     ('rocket://user:pass@localhost/room1/room2', {
-        'instance': plugins.NotifyRocketChat,
+        'instance': NotifyRocketChat,
         # The response text is expected to be the following on a success
         'requests_response_text': {
             'status': 'success',
@@ -123,10 +127,11 @@ apprise_url_tests = (
                 'userId': 'user',
             },
         },
+        'privacy_url': 'rocket://user:****@localhost',
     }),
     # A room and channel
     ('rocket://user:pass@localhost/room/#channel?mode=basic&avatar=Yes', {
-        'instance': plugins.NotifyRocketChat,
+        'instance': NotifyRocketChat,
         # The response text is expected to be the following on a success
         'requests_response_text': {
             'status': 'success',
@@ -142,7 +147,7 @@ apprise_url_tests = (
     # to ensure we get the right mode, we enforce basic mode
     # so that web/token gets interpreted as a password
     ('rockets://user:pass%2Fwithslash@localhost/#channel/?mode=basic', {
-        'instance': plugins.NotifyRocketChat,
+        'instance': NotifyRocketChat,
         # The response text is expected to be the following on a success
         'requests_response_text': {
             'status': 'success',
@@ -151,6 +156,7 @@ apprise_url_tests = (
                 'userId': 'user',
             },
         },
+        'privacy_url': 'rockets://user:****@localhost',
     }),
     # A room and channel
     ('rockets://user:pass@localhost/rooma/#channela', {
@@ -161,54 +167,57 @@ apprise_url_tests = (
             'status': 'failure',
         },
         # Exception is thrown in this case
-        'instance': plugins.NotifyRocketChat,
+        'instance': NotifyRocketChat,
         # Notifications will fail in this event
         'response': False,
     }),
     # A web token
     ('rockets://web/token@localhost/@user/#channel/roomid', {
-        'instance': plugins.NotifyRocketChat,
+        'instance': NotifyRocketChat,
+        'privacy_url': 'rockets://****@localhost/#channel/roomid',
     }),
     ('rockets://user:web/token@localhost/@user/?mode=webhook', {
-        'instance': plugins.NotifyRocketChat,
+        'instance': NotifyRocketChat,
+        'privacy_url': 'rockets://user:****@localhost',
     }),
     ('rockets://user:web/token@localhost?to=@user2,#channel2', {
-        'instance': plugins.NotifyRocketChat,
+        'instance': NotifyRocketChat,
     }),
     ('rockets://web/token@localhost/?avatar=No', {
         # a simple webhook token with default values
-        'instance': plugins.NotifyRocketChat,
+        'instance': NotifyRocketChat,
 
         # Our expected url(privacy=True) startswith() response:
-        'privacy_url': 'rockets://w...n@localhost',
+        'privacy_url': 'rockets://****@localhost/',
     }),
     ('rockets://localhost/@user/?mode=webhook&webhook=web/token', {
-        'instance': plugins.NotifyRocketChat,
+        'instance': NotifyRocketChat,
+        'privacy_url': 'rockets://****@localhost/@user'
     }),
     ('rockets://user:web/token@localhost/@user/?mode=invalid', {
         # invalid mode
         'instance': TypeError,
     }),
     ('rocket://user:pass@localhost:8081/room1/room2', {
-        'instance': plugins.NotifyRocketChat,
+        'instance': NotifyRocketChat,
         # force a failure using basic mode
         'response': False,
         'requests_response_code': requests.codes.internal_server_error,
     }),
     ('rockets://user:web/token@localhost?to=@user3,#channel3', {
-        'instance': plugins.NotifyRocketChat,
+        'instance': NotifyRocketChat,
         # force a failure using webhook mode
         'response': False,
         'requests_response_code': requests.codes.internal_server_error,
     }),
     ('rocket://user:pass@localhost:8082/#channel', {
-        'instance': plugins.NotifyRocketChat,
+        'instance': NotifyRocketChat,
         # throw a bizzare code forcing us to fail to look it up
         'response': False,
         'requests_response_code': 999,
     }),
     ('rocket://user:pass@localhost:8083/#chan1/#chan2/room', {
-        'instance': plugins.NotifyRocketChat,
+        'instance': NotifyRocketChat,
         # Throws a series of connection and transfer exceptions when this flag
         # is set and tests that we gracfully handle them
         'test_requests_exceptions': True,
@@ -228,13 +237,11 @@ def test_plugin_rocket_chat_urls():
 
 @mock.patch('requests.get')
 @mock.patch('requests.post')
-def test_plugin_rocketchat_edge_cases(mock_post, mock_get):
+def test_plugin_rocket_chat_edge_cases(mock_post, mock_get):
     """
     NotifyRocketChat() Edge Cases
 
     """
-    # Disable Throttling to speed testing
-    plugins.NotifyBase.request_rate_per_sec = 0
 
     # Chat ID
     recipients = 'AbcD1245, @l2g, @lead2gold, #channel, #channel2'
@@ -251,16 +258,16 @@ def test_plugin_rocketchat_edge_cases(mock_post, mock_get):
     mock_post.return_value.content = ''
     mock_get.return_value.content = ''
 
-    obj = plugins.NotifyRocketChat(
+    obj = NotifyRocketChat(
         user=user, password=password, targets=recipients)
-    assert isinstance(obj, plugins.NotifyRocketChat) is True
+    assert isinstance(obj, NotifyRocketChat) is True
     assert len(obj.channels) == 2
     assert len(obj.users) == 2
     assert len(obj.rooms) == 1
 
     # No Webhook specified
     with pytest.raises(TypeError):
-        obj = plugins.NotifyRocketChat(webhook=None, mode='webhook')
+        obj = NotifyRocketChat(webhook=None, mode='webhook')
 
     #
     # Logout
