@@ -27,10 +27,10 @@ import os
 from unittest import mock
 
 import requests
-from apprise import plugins
 from apprise import Apprise
 from apprise import AppriseAttachment
 from apprise import NotifyType
+from apprise.plugins.NotifySMTP2Go import NotifySMTP2Go
 from helpers import AppriseURLTester
 
 # Disable logging for a cleaner testing output
@@ -58,57 +58,57 @@ apprise_url_tests = (
         'instance': TypeError,
     }),
     # Invalid from email address
-    ('smtp2go://!@localhost.localdomain/{}-{}-{}'.format(
+    ('smtp2go://"@localhost.localdomain/{}-{}-{}'.format(
         'a' * 32, 'b' * 8, 'c' * 8), {
         'instance': TypeError,
     }),
     # No To email address, but everything else is valid
     ('smtp2go://user@localhost.localdomain/{}-{}-{}'.format(
         'a' * 32, 'b' * 8, 'c' * 8), {
-        'instance': plugins.NotifySMTP2Go,
+        'instance': NotifySMTP2Go,
     }),
     ('smtp2go://user@localhost.localdomain/{}-{}-{}?format=markdown'.format(
         'a' * 32, 'b' * 8, 'c' * 8), {
-        'instance': plugins.NotifySMTP2Go,
+        'instance': NotifySMTP2Go,
     }),
     ('smtp2go://user@localhost.localdomain/{}-{}-{}?format=html'.format(
         'a' * 32, 'b' * 8, 'c' * 8), {
-        'instance': plugins.NotifySMTP2Go,
+        'instance': NotifySMTP2Go,
     }),
     ('smtp2go://user@localhost.localdomain/{}-{}-{}?format=text'.format(
         'a' * 32, 'b' * 8, 'c' * 8), {
-        'instance': plugins.NotifySMTP2Go,
+        'instance': NotifySMTP2Go,
     }),
     # headers
     ('smtp2go://user@localhost.localdomain/{}-{}-{}'
         '?+X-Customer-Campaign-ID=Apprise'.format(
             'a' * 32, 'b' * 8, 'c' * 8), {
-                'instance': plugins.NotifySMTP2Go,
+                'instance': NotifySMTP2Go,
         }),
     # bcc and cc
     ('smtp2go://user@localhost.localdomain/{}-{}-{}'
         '?bcc=user@example.com&cc=user2@example.com'.format(
             'a' * 32, 'b' * 8, 'c' * 8), {
-                'instance': plugins.NotifySMTP2Go,
+                'instance': NotifySMTP2Go,
         }),
     # One To Email address
     ('smtp2go://user@localhost.localdomain/{}-{}-{}/test@example.com'.format(
         'a' * 32, 'b' * 8, 'c' * 8), {
-            'instance': plugins.NotifySMTP2Go,
+            'instance': NotifySMTP2Go,
     }),
     ('smtp2go://user@localhost.localdomain/'
         '{}-{}-{}?to=test@example.com'.format(
             'a' * 32, 'b' * 8, 'c' * 8), {
-                'instance': plugins.NotifySMTP2Go}),
+                'instance': NotifySMTP2Go}),
     # One To Email address, a from name specified too
     ('smtp2go://user@localhost.localdomain/{}-{}-{}/'
         'test@example.com?name="Frodo"'.format(
             'a' * 32, 'b' * 8, 'c' * 8), {
-                'instance': plugins.NotifySMTP2Go}),
+                'instance': NotifySMTP2Go}),
     # Invalid 'To' Email address
     ('smtp2go://user@localhost.localdomain/{}-{}-{}/invalid'.format(
         'a' * 32, 'b' * 8, 'c' * 8), {
-            'instance': plugins.NotifySMTP2Go,
+            'instance': NotifySMTP2Go,
             # Expected notify() response
             'notify_response': False,
     }),
@@ -118,25 +118,25 @@ apprise_url_tests = (
         '/'.join(('user1@example.com', 'invalid', 'User2:user2@example.com')),
         ','.join(('user3@example.com', 'i@v', 'User1:user1@example.com')),
         ','.join(('user4@example.com', 'g@r@b', 'Da:user5@example.com'))), {
-            'instance': plugins.NotifySMTP2Go,
+            'instance': NotifySMTP2Go,
     }),
     ('smtp2go://user@localhost.localdomain/{}-{}-{}'.format(
         'a' * 32, 'b' * 8, 'c' * 8), {
-        'instance': plugins.NotifySMTP2Go,
+        'instance': NotifySMTP2Go,
         # force a failure
         'response': False,
         'requests_response_code': requests.codes.internal_server_error,
     }),
     ('smtp2go://user@localhost.localdomain/{}-{}-{}'.format(
         'a' * 32, 'b' * 8, 'c' * 8), {
-        'instance': plugins.NotifySMTP2Go,
+        'instance': NotifySMTP2Go,
         # throw a bizzare code forcing us to fail to look it up
         'response': False,
         'requests_response_code': 999,
     }),
     ('smtp2go://user@localhost.localdomain/{}-{}-{}'.format(
         'a' * 32, 'b' * 8, 'c' * 8), {
-        'instance': plugins.NotifySMTP2Go,
+        'instance': NotifySMTP2Go,
         # Throws a series of connection and transfer exceptions when this flag
         # is set and tests that we gracfully handle them
         'test_requests_exceptions': True,
@@ -160,8 +160,6 @@ def test_plugin_smtp2go_attachments(mock_post):
     NotifySMTP2Go() Attachments
 
     """
-    # Disable Throttling to speed testing
-    plugins.NotifyBase.request_rate_per_sec = 0
 
     okay_response = requests.Request()
     okay_response.status_code = requests.codes.ok
@@ -175,7 +173,7 @@ def test_plugin_smtp2go_attachments(mock_post):
 
     obj = Apprise.instantiate(
         'smtp2go://user@localhost.localdomain/{}'.format(apikey))
-    assert isinstance(obj, plugins.NotifySMTP2Go)
+    assert isinstance(obj, NotifySMTP2Go)
 
     # Test Valid Attachment
     path = os.path.join(TEST_VAR_DIR, 'apprise-test.gif')
@@ -218,7 +216,7 @@ def test_plugin_smtp2go_attachments(mock_post):
     obj = Apprise.instantiate(
         'smtp2go://no-reply@example.com/{}/'
         'user1@example.com/user2@example.com?batch=yes'.format(apikey))
-    assert isinstance(obj, plugins.NotifySMTP2Go)
+    assert isinstance(obj, NotifySMTP2Go)
 
     # Force our batch to break into separate messages
     obj.default_batch_size = 1
