@@ -24,6 +24,7 @@
 # THE SOFTWARE.
 
 import os
+import sys
 from unittest import mock
 
 import pytest
@@ -31,9 +32,9 @@ import requests
 from json import dumps
 from datetime import datetime
 from apprise import Apprise
-from apprise import plugins
 from apprise import NotifyType
 from apprise import AppriseAttachment
+from apprise.plugins.NotifyTwitter import NotifyTwitter
 from helpers import AppriseURLTester
 
 # Disable logging for a cleaner testing output
@@ -63,24 +64,24 @@ apprise_url_tests = (
         # Missing Keys
         'instance': TypeError,
     }),
-    ('twitter://consumer_key/consumer_secret/access_token/', {
+    ('twitter://consumer_key/consumer_secret/atoken1/', {
         # Missing Access Secret
         'instance': TypeError,
     }),
-    ('twitter://consumer_key/consumer_secret/access_token/access_secret', {
+    ('twitter://consumer_key/consumer_secret/atoken2/access_secret', {
         # No user mean's we message ourselves
-        'instance': plugins.NotifyTwitter,
+        'instance': NotifyTwitter,
         # Expected notify() response False (because we won't be able
         # to detect our user)
         'notify_response': False,
 
         # Our expected url(privacy=True) startswith() response:
-        'privacy_url': 'twitter://c...y/****/a...n/****',
+        'privacy_url': 'twitter://c...y/****/a...2/****',
     }),
-    ('twitter://consumer_key/consumer_secret/access_token/access_secret'
+    ('twitter://consumer_key/consumer_secret/atoken3/access_secret'
         '?cache=no', {
             # No user mean's we message ourselves
-            'instance': plugins.NotifyTwitter,
+            'instance': NotifyTwitter,
             # However we'll be okay if we return a proper response
             'requests_response_text': {
                 'id': 12345,
@@ -89,9 +90,9 @@ apprise_url_tests = (
                 'media_id': 123,
             },
         }),
-    ('twitter://consumer_key/consumer_secret/access_token/access_secret', {
+    ('twitter://consumer_key/consumer_secret/atoken4/access_secret', {
         # No user mean's we message ourselves
-        'instance': plugins.NotifyTwitter,
+        'instance': NotifyTwitter,
         # However we'll be okay if we return a proper response
         'requests_response_text': {
             'id': 12345,
@@ -101,9 +102,9 @@ apprise_url_tests = (
         },
     }),
     # A duplicate of the entry above, this will cause cache to be referenced
-    ('twitter://consumer_key/consumer_secret/access_token/access_secret', {
+    ('twitter://consumer_key/consumer_secret/atoken5/access_secret', {
         # No user mean's we message ourselves
-        'instance': plugins.NotifyTwitter,
+        'instance': NotifyTwitter,
         # However we'll be okay if we return a proper response
         'requests_response_text': {
             'id': 12345,
@@ -114,9 +115,9 @@ apprise_url_tests = (
     }),
     # handle cases where the screen_name is missing from the response causing
     # an exception during parsing
-    ('twitter://consumer_key/consumer_secret2/access_token/access_secret', {
+    ('twitter://consumer_key/consumer_secret2/atoken6/access_secret', {
         # No user mean's we message ourselves
-        'instance': plugins.NotifyTwitter,
+        'instance': NotifyTwitter,
         # However we'll be okay if we return a proper response
         'requests_response_text': {
             'id': 12345,
@@ -126,48 +127,47 @@ apprise_url_tests = (
         # due to a mangled response_text we'll fail
         'notify_response': False,
     }),
-    ('twitter://user@consumer_key/csecret2/access_token/access_secret/-/%/', {
+    ('twitter://user@consumer_key/csecret2/atoken7/access_secret/-/%/', {
         # One Invalid User
-        'instance': plugins.NotifyTwitter,
+        'instance': NotifyTwitter,
         # Expected notify() response False (because we won't be able
         # to detect our user)
         'notify_response': False,
     }),
-    ('twitter://user@consumer_key/csecret/access_token/access_secret'
+    ('twitter://user@consumer_key/csecret/atoken8/access_secret'
         '?cache=No&batch=No', {
             # No Cache & No Batch
-            'instance': plugins.NotifyTwitter,
+            'instance': NotifyTwitter,
             'requests_response_text': [{
                 'id': 12345,
                 'screen_name': 'user'
             }],
         }),
-    ('twitter://user@consumer_key/csecret/access_token/access_secret', {
+    ('twitter://user@consumer_key/csecret/atoken9/access_secret', {
         # We're good!
-        'instance': plugins.NotifyTwitter,
+        'instance': NotifyTwitter,
         'requests_response_text': [{
             'id': 12345,
             'screen_name': 'user'
         }],
     }),
-    # A duplicate of the entry above, this will cause cache to be referenced
-    # for this reason, we don't even need to return a valid response
-    ('twitter://user@consumer_key/csecret/access_token/access_secret', {
+    ('twitter://user@consumer_key/csecret/atoken11/access_secret', {
         # We're identifying the same user we already sent to
-        'instance': plugins.NotifyTwitter,
+        'instance': NotifyTwitter,
+        'notify_response': False,
     }),
-    ('twitter://ckey/csecret/access_token/access_secret?mode=tweet', {
+    ('tweet://ckey/csecret/atoken12/access_secret', {
         # A Public Tweet
-        'instance': plugins.NotifyTwitter,
+        'instance': NotifyTwitter,
     }),
-    ('twitter://user@ckey/csecret/access_token/access_secret?mode=invalid', {
+    ('twitter://user@ckey/csecret/atoken13/access_secret?mode=invalid', {
         # An invalid mode
         'instance': TypeError,
     }),
-    ('twitter://usera@consumer_key/consumer_secret/access_token/'
+    ('twitter://usera@consumer_key/consumer_secret/atoken14/'
         'access_secret/user/?to=userb', {
             # We're good!
-            'instance': plugins.NotifyTwitter,
+            'instance': NotifyTwitter,
             'requests_response_text': [{
                 'id': 12345,
                 'screen_name': 'usera'
@@ -179,20 +179,20 @@ apprise_url_tests = (
                 'id': 123,
             }],
         }),
-    ('twitter://ckey/csecret/access_token/access_secret', {
-        'instance': plugins.NotifyTwitter,
+    ('twitter://ckey/csecret/atoken15/access_secret', {
+        'instance': NotifyTwitter,
         # throw a bizzare code forcing us to fail to look it up
         'response': False,
         'requests_response_code': 999,
     }),
-    ('twitter://ckey/csecret/access_token/access_secret', {
-        'instance': plugins.NotifyTwitter,
+    ('twitter://ckey/csecret/atoken16/access_secret', {
+        'instance': NotifyTwitter,
         # Throws a series of connection and transfer exceptions when this flag
         # is set and tests that we gracfully handle them
         'test_requests_exceptions': True,
     }),
-    ('twitter://ckey/csecret/access_token/access_secret?mode=tweet', {
-        'instance': plugins.NotifyTwitter,
+    ('twitter://ckey/csecret/atoken17/access_secret?mode=tweet', {
+        'instance': NotifyTwitter,
         # Throws a series of connection and transfer exceptions when this flag
         # is set and tests that we gracfully handle them
         'test_requests_exceptions': True,
@@ -228,9 +228,6 @@ def test_plugin_twitter_general(mock_post, mock_get):
         'id': 9876,
     }]
 
-    # Disable Throttling to speed testing
-    plugins.NotifyBase.request_rate_per_sec = 0
-
     # Epoch time:
     epoch = datetime.utcfromtimestamp(0)
 
@@ -247,14 +244,14 @@ def test_plugin_twitter_general(mock_post, mock_get):
     mock_post.return_value = request
 
     # Variation Initializations
-    obj = plugins.NotifyTwitter(
+    obj = NotifyTwitter(
         ckey=ckey,
         csecret=csecret,
         akey=akey,
         asecret=asecret,
         targets=screen_name)
 
-    assert isinstance(obj, plugins.NotifyTwitter) is True
+    assert isinstance(obj, NotifyTwitter) is True
     assert isinstance(obj.url(), str) is True
 
     # apprise room was found
@@ -322,7 +319,7 @@ def test_plugin_twitter_general(mock_post, mock_get):
     assert obj.send(body="test") is True
 
     # Flush our cache forcing it's re-creating
-    del plugins.NotifyTwitter._user_cache
+    NotifyTwitter._user_cache = {}
     assert obj.send(body="test") is True
 
     # Cause content response to be None
@@ -336,7 +333,7 @@ def test_plugin_twitter_general(mock_post, mock_get):
     # Return it to a parseable string
     request.content = '{}'
 
-    results = plugins.NotifyTwitter.parse_url(
+    results = NotifyTwitter.parse_url(
         'twitter://{}/{}/{}/{}?to={}'.format(
             ckey, csecret, akey, asecret, screen_name))
     assert isinstance(results, dict) is True
@@ -352,7 +349,7 @@ def test_plugin_twitter_general(mock_post, mock_get):
     # Set ourselves up to handle whoami calls
 
     # Flush out our cache
-    del plugins.NotifyTwitter._user_cache
+    NotifyTwitter._user_cache = {}
 
     response_obj = {
         'screen_name': screen_name,
@@ -360,7 +357,7 @@ def test_plugin_twitter_general(mock_post, mock_get):
     }
     request.content = dumps(response_obj)
 
-    obj = plugins.NotifyTwitter(
+    obj = NotifyTwitter(
         ckey=ckey,
         csecret=csecret,
         akey=akey,
@@ -369,12 +366,12 @@ def test_plugin_twitter_general(mock_post, mock_get):
     assert obj.send(body="test") is True
 
     # Alter the key forcing us to look up a new value of ourselves again
-    del plugins.NotifyTwitter._user_cache
-    del plugins.NotifyTwitter._whoami_cache
+    NotifyTwitter._user_cache = {}
+    NotifyTwitter._whoami_cache = None
     obj.ckey = 'different.then.it.was'
     assert obj.send(body="test") is True
 
-    del plugins.NotifyTwitter._whoami_cache
+    NotifyTwitter._whoami_cache = None
     obj.ckey = 'different.again'
     assert obj.send(body="test") is True
 
@@ -386,41 +383,44 @@ def test_plugin_twitter_edge_cases():
     """
 
     with pytest.raises(TypeError):
-        plugins.NotifyTwitter(
+        NotifyTwitter(
             ckey=None, csecret=None, akey=None, asecret=None)
 
     with pytest.raises(TypeError):
-        plugins.NotifyTwitter(
+        NotifyTwitter(
             ckey='value', csecret=None, akey=None, asecret=None)
 
     with pytest.raises(TypeError):
-        plugins.NotifyTwitter(
+        NotifyTwitter(
             ckey='value', csecret='value', akey=None, asecret=None)
 
     with pytest.raises(TypeError):
-        plugins.NotifyTwitter(
+        NotifyTwitter(
             ckey='value', csecret='value', akey='value', asecret=None)
 
     assert isinstance(
-        plugins.NotifyTwitter(
+        NotifyTwitter(
             ckey='value', csecret='value', akey='value', asecret='value'),
-        plugins.NotifyTwitter,
+        NotifyTwitter,
     )
 
     assert isinstance(
-        plugins.NotifyTwitter(
+        NotifyTwitter(
             ckey='value', csecret='value', akey='value', asecret='value',
             user='l2gnux'),
-        plugins.NotifyTwitter,
+        NotifyTwitter,
     )
 
     # Invalid Target User
     with pytest.raises(TypeError):
-        plugins.NotifyTwitter(
+        NotifyTwitter(
             ckey='value', csecret='value', akey='value', asecret='value',
             targets='%G@rB@g3')
 
 
+@pytest.mark.skipif(
+    hasattr(sys, "pypy_version_info") and sys.version_info < (3, 7),
+    reason="Does not work or is flaky on PyPy 3.6")
 @mock.patch('requests.post')
 @mock.patch('requests.get')
 def test_plugin_twitter_dm_attachments(mock_get, mock_post):
@@ -439,13 +439,17 @@ def test_plugin_twitter_dm_attachments(mock_get, mock_post):
         'id': 9876,
     }
 
-    # Disable Throttling to speed testing
-    plugins.NotifyBase.request_rate_per_sec = 0
+    # Epoch time:
+    epoch = datetime.utcfromtimestamp(0)
 
     # Prepare a good DM response
     good_dm_response = mock.Mock()
     good_dm_response.content = dumps(good_dm_response_obj)
     good_dm_response.status_code = requests.codes.ok
+    good_dm_response.headers = {
+        'x-rate-limit-reset': (datetime.utcnow() - epoch).total_seconds(),
+        'x-rate-limit-remaining': 1,
+    }
 
     # Prepare bad response
     bad_response = mock.Mock()
@@ -542,7 +546,10 @@ def test_plugin_twitter_dm_attachments(mock_get, mock_post):
         body='body', title='title', notify_type=NotifyType.INFO,
         attach=attach) is False
 
-    assert mock_get.call_count == 0
+    assert mock_get.call_count == 1
+    assert mock_get.call_args_list[0][0][0] == \
+        'https://api.twitter.com/1.1/account/verify_credentials.json'
+
     # No get request as cached response is used
     assert mock_post.call_count == 2
     assert mock_post.call_args_list[0][0][0] == \
@@ -658,9 +665,6 @@ def test_plugin_twitter_tweet_attachments(mock_get, mock_post):
         'id': 9876,
     }
 
-    # Disable Throttling to speed testing
-    plugins.NotifyBase.request_rate_per_sec = 0
-
     # Prepare a good DM response
     good_tweet_response = mock.Mock()
     good_tweet_response.content = dumps(good_tweet_response_obj)
