@@ -23,8 +23,8 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 import requests
-from apprise import plugins
 from apprise import NotifyType
+from apprise.plugins.NotifyXBMC import NotifyXBMC
 from helpers import AppriseURLTester
 
 # Disable logging for a cleaner testing output
@@ -40,63 +40,63 @@ apprise_url_tests = (
         'instance': None,
     }),
     ('kodi://localhost', {
-        'instance': plugins.NotifyXBMC,
+        'instance': NotifyXBMC,
     }),
     ('kodi://192.168.4.1', {
         # Support IPv4 Addresses
-        'instance': plugins.NotifyXBMC,
+        'instance': NotifyXBMC,
     }),
     ('kodi://[2001:db8:002a:3256:adfe:05c0:0003:0006]', {
         # Support IPv6 Addresses
-        'instance': plugins.NotifyXBMC,
+        'instance': NotifyXBMC,
         # Privacy URL
         'privacy_url': 'kodi://[2001:db8:002a:3256:adfe:05c0:0003:0006]',
     }),
     ('kodi://[2001:db8:002a:3256:adfe:05c0:0003:0006]:8282', {
         # Support IPv6 Addresses with port
-        'instance': plugins.NotifyXBMC,
+        'instance': NotifyXBMC,
         # Privacy URL
         'privacy_url': 'kodi://[2001:db8:002a:3256:adfe:05c0:0003:0006]:8282',
     }),
     ('kodi://user:pass@localhost', {
-        'instance': plugins.NotifyXBMC,
+        'instance': NotifyXBMC,
 
         # Our expected url(privacy=True) startswith() response:
         'privacy_url': 'kodi://user:****@localhost',
     }),
     ('kodi://localhost:8080', {
-        'instance': plugins.NotifyXBMC,
+        'instance': NotifyXBMC,
     }),
     ('kodi://user:pass@localhost:8080', {
-        'instance': plugins.NotifyXBMC,
+        'instance': NotifyXBMC,
     }),
     ('kodis://localhost', {
-        'instance': plugins.NotifyXBMC,
+        'instance': NotifyXBMC,
     }),
     ('kodis://user:pass@localhost', {
-        'instance': plugins.NotifyXBMC,
+        'instance': NotifyXBMC,
     }),
     ('kodis://localhost:8080/path/', {
-        'instance': plugins.NotifyXBMC,
+        'instance': NotifyXBMC,
     }),
     ('kodis://user:password@localhost:8080', {
-        'instance': plugins.NotifyXBMC,
+        'instance': NotifyXBMC,
 
         # Our expected url(privacy=True) startswith() response:
         'privacy_url': 'kodis://user:****@localhost:8080',
     }),
     ('kodi://localhost', {
-        'instance': plugins.NotifyXBMC,
+        'instance': NotifyXBMC,
         # Experement with different notification types
         'notify_type': NotifyType.WARNING,
     }),
     ('kodi://localhost', {
-        'instance': plugins.NotifyXBMC,
+        'instance': NotifyXBMC,
         # Experement with different notification types
         'notify_type': NotifyType.FAILURE,
     }),
     ('kodis://localhost:443', {
-        'instance': plugins.NotifyXBMC,
+        'instance': NotifyXBMC,
         # don't include an image by default
         'include_image': False,
     }),
@@ -104,19 +104,19 @@ apprise_url_tests = (
         'instance': None,
     }),
     ('kodi://user:pass@localhost:8081', {
-        'instance': plugins.NotifyXBMC,
+        'instance': NotifyXBMC,
         # force a failure
         'response': False,
         'requests_response_code': requests.codes.internal_server_error,
     }),
     ('kodi://user:pass@localhost:8082', {
-        'instance': plugins.NotifyXBMC,
+        'instance': NotifyXBMC,
         # throw a bizzare code forcing us to fail to look it up
         'response': False,
         'requests_response_code': 999,
     }),
     ('kodi://user:pass@localhost:8083', {
-        'instance': plugins.NotifyXBMC,
+        'instance': NotifyXBMC,
         # Throws a series of connection and transfer exceptions when this flag
         # is set and tests that we gracfully handle them
         'test_requests_exceptions': True,
@@ -130,38 +130,38 @@ apprise_url_tests = (
         'instance': None,
     }),
     ('xbmc://localhost', {
-        'instance': plugins.NotifyXBMC,
+        'instance': NotifyXBMC,
     }),
     ('xbmc://localhost?duration=14', {
-        'instance': plugins.NotifyXBMC,
+        'instance': NotifyXBMC,
     }),
     ('xbmc://localhost?duration=invalid', {
-        'instance': plugins.NotifyXBMC,
+        'instance': NotifyXBMC,
     }),
     ('xbmc://localhost?duration=-1', {
-        'instance': plugins.NotifyXBMC,
+        'instance': NotifyXBMC,
     }),
     ('xbmc://user:pass@localhost', {
-        'instance': plugins.NotifyXBMC,
+        'instance': NotifyXBMC,
     }),
     ('xbmc://localhost:8080', {
-        'instance': plugins.NotifyXBMC,
+        'instance': NotifyXBMC,
     }),
     ('xbmc://user:pass@localhost:8080', {
-        'instance': plugins.NotifyXBMC,
+        'instance': NotifyXBMC,
     }),
     ('xbmc://user@localhost', {
-        'instance': plugins.NotifyXBMC,
+        'instance': NotifyXBMC,
         # don't include an image by default
         'include_image': False,
     }),
     ('xbmc://localhost', {
-        'instance': plugins.NotifyXBMC,
+        'instance': NotifyXBMC,
         # Experement with different notification types
         'notify_type': NotifyType.WARNING,
     }),
     ('xbmc://localhost', {
-        'instance': plugins.NotifyXBMC,
+        'instance': NotifyXBMC,
         # Experement with different notification types
         'notify_type': NotifyType.FAILURE,
     }),
@@ -169,19 +169,19 @@ apprise_url_tests = (
         'instance': None,
     }),
     ('xbmc://user:pass@localhost:8081', {
-        'instance': plugins.NotifyXBMC,
+        'instance': NotifyXBMC,
         # force a failure
         'response': False,
         'requests_response_code': requests.codes.internal_server_error,
     }),
     ('xbmc://user:pass@localhost:8082', {
-        'instance': plugins.NotifyXBMC,
+        'instance': NotifyXBMC,
         # throw a bizzare code forcing us to fail to look it up
         'response': False,
         'requests_response_code': 999,
     }),
     ('xbmc://user:pass@localhost:8083', {
-        'instance': plugins.NotifyXBMC,
+        'instance': NotifyXBMC,
         # Throws a series of connection and transfer exceptions when this flag
         # is set and tests that we gracfully handle them
         'test_requests_exceptions': True,
